package info.aspirecn.rdc.iov.sjjh.servicenode.supplier.yh.action;

import info.aspirecn.iov.sjjh.commons.lang.ChannelTypeHandleResponseObject;
import info.aspirecn.iov.sjjh.commons.lang.Constant;
import info.aspirecn.rdc.aspirecloud.node.except.utils.ErrorUtils;
import info.aspirecn.rdc.iov.sjjh.servicenode.supplier.yh.constant.SjjhConstant;
import info.aspirecn.rdc.iov.sjjh.servicenode.supplier.yh.service.YHChannelService;
import info.aspirecn.rdc.iov.sjjh.servicenode.supplier.yh.utils.LocationSupplierProperties;
import info.aspirecn.rdc.iov.sjjh.servicenode.supplier.yh.utils.SupplierProperties;
import info.aspirecn.rdc.iov.sjjh.servicenode.supplier.yh.vo.TwoParamIdCardResponseObject;
import info.aspirecn.rdc.iov.sjjh.servicenode.supplier.yh_interface.action.YHChannelAction;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.tomcat.util.codec.binary.Base64;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;


import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.io.UnsupportedEncodingException;

/**
 * @Auther jianggang
 * @Date 2018/10/25 15:54:40
 * @Description
 */

@Slf4j
@RestController
public class YHChannelActionImpl implements YHChannelAction {
    @Autowired
    YHChannelService yhChannelService;
    @Autowired
    LocationSupplierProperties locationSupplierProperties;

    private String xRresponseCode = "x-responseCode";
    private String xIsCharge = "x-isCharge";


    @Autowired
    private SupplierProperties property;
    @Override
    public ChannelTypeHandleResponseObject twoParamIdCard(
            @RequestHeader(value = "channelId", required = true) String channelId,
            @RequestParam(value = "outTime", required = false) Integer outTime,
            @RequestParam(value = "customBody", required = true) String customBody) {
        log.info("云海身份证二要素请求--->channelId:{}--->outTime:{},--->customBody:{}",channelId,outTime,customBody);
        ChannelTypeHandleResponseObject responseObject = yhChannelService.sendTwoParamIdCardRequest(channelId,outTime,customBody);
        ServletRequestAttributes servletRequestAttributes = (ServletRequestAttributes)RequestContextHolder.getRequestAttributes();
        HttpServletRequest request = servletRequestAttributes.getRequest();
        request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);
        if(responseObject.getCode() != 1){
            request.setAttribute(xRresponseCode,Constant.CHANNEL_LOG_ERROR_CODE);
        }else{
        	 if(Constant.CUSTOMER_RETURN_JK.equals(request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA))){
             	String code = property.getCode().get(responseObject.getResultCode());
             	if(code!=null){
             		responseObject.setResultCode(Integer.valueOf(code));
             	}
             }
             if(property.getDesc().get(responseObject.getResultCode())!=null){
             	responseObject.setResultDesc(property.getDesc().get(responseObject.getResultCode()));
             }
            request.setAttribute(xRresponseCode,Constant.CHANNEL_LOG_SUCCESS_CODE);
        }
       
        if(customBody != null){
            try {
                request.setAttribute(Constant.CHANNEL_LOG_QUERY,Base64.encodeBase64String(customBody.getBytes("utf-8")));
            } catch (UnsupportedEncodingException e) {
                log.error("",e);
            }
        }
        request.setAttribute(xIsCharge,responseObject.getIsCharge());
        Object object = responseObject.getResultBody();
        if(object != null){
        	String upStreamCode = ((TwoParamIdCardResponseObject)responseObject.getResultBody()).getCode();
            request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE,String.valueOf(upStreamCode));
        }else{
            request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE,Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE);
        }
        return responseObject;
    }


  
    @Override
    public ChannelTypeHandleResponseObject checkLocationForYH(
    		@RequestHeader(value = "channelId", required = true) String channelId,
            @RequestParam(value = "outTime", required = false) Integer outTime,
            @RequestParam(value = "customBody", required = true) String customBody){
    	 log.info("地理位置校验请求--->channelId:{}--->outTime:{},--->customBody:{}",channelId,outTime,customBody);
    	 HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
 				.getRequest();
 		try {
 			//把请求参数放入
     		request.setAttribute(Constant.CHANNEL_LOG_QUERY, 
     				Base64.encodeBase64String(customBody.getBytes(SjjhConstant.UTF8_ENCODE)));
 		} catch (IOException ex) {
 			 log.error("", ex);
 		}
         
 		ChannelTypeHandleResponseObject ret = yhChannelService.checkLocation(request, customBody, outTime);
 		
     	if(ret.getCode() != Constant.SUCCESS) {
     		request.setAttribute(xRresponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
     	} else {
     		if(Constant.CUSTOMER_RETURN_JK.equals(request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA))){
     			String code = locationSupplierProperties.getCode().get(ret.getResultCode());
     			if(code!=null){
     				ret.setResultCode(Integer.parseInt(code));
     			}
     		}
     		 if(locationSupplierProperties.getDesc().get(ret.getResultCode())!=null){
     			ret.setResultDesc(property.getDesc().get(ret.getResultCode()));
             }
     		request.setAttribute(xRresponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
     	}
     	request.setAttribute(xIsCharge, ret.getIsCharge());  	
     	request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);
         return ret;
    }
    
    @Override
	@ApiOperation(value = "云海电信三要素检验接口 " , notes = "")
	public ChannelTypeHandleResponseObject yhDianXinCheck(
    		@RequestHeader(name="channelId")  String channelId,
    		@RequestParam(name = "outTime", required = true) int outTime,
    		@RequestParam(name = "customBody", required = true) String customBody) {
		HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();
		try {
			//把请求参数放入
    		request.setAttribute(Constant.CHANNEL_LOG_QUERY, 
    				Base64.encodeBase64String(customBody.getBytes(SjjhConstant.UTF8_ENCODE)));
		} catch (IOException ex) {
			ErrorUtils.captureException(ex);
		}
        
		
		ChannelTypeHandleResponseObject ret = yhChannelService.yhDianXinCheck(request, customBody, outTime);

			
    	if(ret.getCode() != Constant.SUCCESS) {
    		request.setAttribute(xRresponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
    	} else {
    		request.setAttribute(xRresponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
    	}
    	request.setAttribute(xIsCharge, ret.getIsCharge());
    	request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);
        
        return ret;
		
	}
    
	@Override
    @ApiOperation(value = "云海联通三要素检验接口 " , notes = "")
	public ChannelTypeHandleResponseObject yhLianTongCheck(
    		@RequestHeader(name="channelId")  String channelId,
    		@RequestParam(name = "outTime", required = true) int outTime,
    		@RequestParam(name = "customBody", required = true) String customBody) {
    	HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();
		try {
			//把请求参数放入
    		request.setAttribute(Constant.CHANNEL_LOG_QUERY, 
    				Base64.encodeBase64String(customBody.getBytes(SjjhConstant.UTF8_ENCODE)));
		} catch (IOException ex) {
			ErrorUtils.captureException(ex);
		}
        
		
		ChannelTypeHandleResponseObject ret = yhChannelService.yhLianTongCheck(request, customBody, outTime);
			
    	if(ret.getCode() != Constant.SUCCESS) {
    		request.setAttribute(xRresponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
    	} else {
    		request.setAttribute(xRresponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
    	}
    	request.setAttribute(xIsCharge, ret.getIsCharge());
    	request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);
        
        return ret;
    	
    }
	
	@Override
    @ApiOperation(value = "云海联通在线时长接口" , notes = "")
	public ChannelTypeHandleResponseObject lianTongOnlineTimeCheck(
    		@RequestHeader(name="channelId")  String channelId,
    		@RequestParam(name = "outTime", required = true) int outTime,
    		@RequestParam(name = "customBody", required = true) String customBody) {
    	HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();
		try {
			//把请求参数放入
    		request.setAttribute(Constant.CHANNEL_LOG_QUERY, 
    				Base64.encodeBase64String(customBody.getBytes(SjjhConstant.UTF8_ENCODE)));
		} catch (IOException ex) {
			ErrorUtils.captureException(ex);
		}
        
		
		ChannelTypeHandleResponseObject ret = yhChannelService.yhLianTongOnlineTimeCheck(
				request, customBody, outTime);
    	if(ret.getCode() != Constant.SUCCESS) {
    		request.setAttribute(xRresponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
    	} else {
    		request.setAttribute(xRresponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
    	}
    	request.setAttribute(xIsCharge, ret.getIsCharge());
    	request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);
        
        return ret;
    	
    }
	
	
	@Override
    @ApiOperation(value = "云海联通在网状态接口" , notes = "")
	public ChannelTypeHandleResponseObject lianTongOnlineStatusCheck(
    		@RequestHeader(name="channelId")  String channelId,
    		@RequestParam(name = "outTime", required = true) int outTime,
    		@RequestParam(name = "customBody", required = true) String customBody) {
    	HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();
		try {
			//把请求参数放入
    		request.setAttribute(Constant.CHANNEL_LOG_QUERY, 
    				Base64.encodeBase64String(customBody.getBytes(SjjhConstant.UTF8_ENCODE)));
		} catch (IOException ex) {
			ErrorUtils.captureException(ex);
		}
        
		
		ChannelTypeHandleResponseObject ret = yhChannelService.yhLianTongOnlineStatusCheck(
				request, customBody, outTime);
			
    	if(ret.getCode() != Constant.SUCCESS) {
    		request.setAttribute(xRresponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
    	} else {
    		request.setAttribute(xRresponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
    	}
    	request.setAttribute(xIsCharge, ret.getIsCharge());
    	request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);
        
        return ret;
    	
    }
	
	@Override
    @PostMapping(value = "/checkCMCCMobileOnlineTime.do")
	public ChannelTypeHandleResponseObject checkCMCCMobileOnlineTime(@RequestHeader(name = "channelId") String channelId,
            @RequestParam(name = "outTime") int outTime,
            @RequestParam(name = "customBody") String customBody) {
	    log.info("移动在网时长查询--->channelId:{}--->outTime:{},--->customBody:{}",channelId,outTime,customBody);

	    HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
	            .getRequest();

	    //调用service
	    ChannelTypeHandleResponseObject responseObject = yhChannelService.checkCMCCMobileOnlineTime(request, customBody, outTime);

	    //把接口参数、调用结果和是否收费放入访问日志中
	    if(responseObject.getCode() != Constant.SUCCESS) {
	        request.setAttribute(xRresponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
	    } else {
	        request.setAttribute(xRresponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
	    }
	    request.setAttribute(xIsCharge, responseObject.getIsCharge());

	    try {
	        request.setAttribute(Constant.CHANNEL_LOG_QUERY,
	                Base64.encodeBase64String(customBody.getBytes(SjjhConstant.UTF8_ENCODE)));
	    } catch (Exception ex) {
	        ErrorUtils.captureException(ex);
	    }

	    request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);
	    return responseObject;
	}
	
	@Override
	@PostMapping(value = "/checkCMCCMobileOnlineStatus.do")
	public ChannelTypeHandleResponseObject checkCMCCMobileOnlineStatus(@RequestHeader(name = "channelId") String channelId,
            @RequestParam(name = "outTime") int outTime,
            @RequestParam(name = "customBody") String customBody) {
	    log.info("移动在网状态查询--->channelId:{}--->outTime:{},--->customBody:{}",channelId,outTime,customBody);

	    HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
	            .getRequest();

	    //调用service
	    ChannelTypeHandleResponseObject responseObject = yhChannelService.checkCMCCMobileOnlineStatus(request, customBody, outTime);

	    //把接口参数、调用结果和是否收费放入访问日志中
	    if(responseObject.getCode() != Constant.SUCCESS) {
	        request.setAttribute(xRresponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
	    } else {
	        request.setAttribute(xRresponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
	    }
	    request.setAttribute(xIsCharge, responseObject.getIsCharge());

	    try {
	        request.setAttribute(Constant.CHANNEL_LOG_QUERY,
	                Base64.encodeBase64String(customBody.getBytes(SjjhConstant.UTF8_ENCODE)));
	    } catch (Exception ex) {
	        ErrorUtils.captureException(ex);
	    }

	    request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);
	    return responseObject;
	}
	
	@Override
	public ChannelTypeHandleResponseObject lianTongCostScore(
    		@RequestHeader(name="channelId")  String channelId,
    		@RequestParam(name = "outTime", required = true) int outTime,
    		@RequestParam(name = "customBody", required = true) String customBody) {
    	HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();
		try {
			//把请求参数放入
    		request.setAttribute(Constant.CHANNEL_LOG_QUERY, 
    				Base64.encodeBase64String(customBody.getBytes(SjjhConstant.UTF8_ENCODE)));
		} catch (IOException ex) {
			ErrorUtils.captureException(ex);
		}
        
		
		ChannelTypeHandleResponseObject ret = yhChannelService.lianTongCostScore(request, customBody, outTime);
			
    	if(ret.getCode() != Constant.SUCCESS) {
    		request.setAttribute(xRresponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
    	} else {
    		request.setAttribute(xRresponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
    	}
    	request.setAttribute(xIsCharge, ret.getIsCharge());
    	request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);
        
        return ret;
    	
    }
	
	@Override
	public ChannelTypeHandleResponseObject dianXinMonthCost(
    		@RequestHeader(name="channelId")  String channelId,
    		@RequestParam(name = "outTime", required = true) int outTime,
    		@RequestParam(name = "customBody", required = true) String customBody) {
    	HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();
		try {
			//把请求参数放入
    		request.setAttribute(Constant.CHANNEL_LOG_QUERY, 
    				Base64.encodeBase64String(customBody.getBytes(SjjhConstant.UTF8_ENCODE)));
		} catch (IOException ex) {
			ErrorUtils.captureException(ex);
		}
        
		
		ChannelTypeHandleResponseObject ret = yhChannelService.dianXinMonthCost(request, customBody, outTime);
			
    	if(ret.getCode() != Constant.SUCCESS) {
    		request.setAttribute(xRresponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
    	} else {
    		request.setAttribute(xRresponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
    	}
    	request.setAttribute(xIsCharge, ret.getIsCharge());
    	request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);
        
        return ret;
    	
    }
	
	@Override
	public ChannelTypeHandleResponseObject queryMobileConsumeSection(@RequestHeader(name = "channelId") String channelId,
            @RequestParam(name = "outTime") int outTime,
            @RequestParam(name = "customBody") String customBody) {
	    log.info("移动手机消费区间查询接口--->channelId:{}--->outTime:{},--->customBody:{}",channelId,outTime,customBody);

	    HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
	            .getRequest();

	    //调用service
	    ChannelTypeHandleResponseObject responseObject = yhChannelService.queryMobileConsumeSection(request, customBody, outTime);

	    //把接口参数、调用结果和是否收费放入访问日志中
	    if(responseObject.getCode() != Constant.SUCCESS) {
	        request.setAttribute(xRresponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
	    } else {
	        request.setAttribute(xRresponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
	    }
	    request.setAttribute(xIsCharge, responseObject.getIsCharge());

	    try {
	        request.setAttribute(Constant.CHANNEL_LOG_QUERY,
	                Base64.encodeBase64String(customBody.getBytes(SjjhConstant.UTF8_ENCODE)));
	    } catch (Exception ex) {
	        ErrorUtils.captureException(ex);
	    }

	    request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);
	    return responseObject;
	}

}
