package info.aspirecn.rdc.iov.sjjh.servicenode.supplier.yh.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.fasterxml.jackson.databind.ObjectMapper;
import info.aspirecn.iov.sjjh.commons.lang.ChannelTypeHandleResponseObject;
import info.aspirecn.iov.sjjh.commons.lang.Constant;
import info.aspirecn.iov.sjjh.commons.lang.PatternTools;
import info.aspirecn.rdc.aspirecloud.node.except.utils.ErrorUtils;
import info.aspirecn.rdc.iov.sjjh.servicenode.supplier.yh.constant.SjjhConstant;
import info.aspirecn.rdc.iov.sjjh.servicenode.supplier.yh.service.DrivingLicenseService;
import info.aspirecn.rdc.iov.sjjh.servicenode.supplier.yh.utils.Utils;
import info.aspirecn.rdc.iov.sjjh.servicenode.supplier.yh.vo.DrivingLicenseJsonResolveObject;
import info.aspirecn.rdc.iov.sjjh.servicenode.supplier.yh.vo.DrivingLicenseResponseObject;
import lombok.extern.slf4j.Slf4j;
import okhttp3.FormBody;
import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.Response;
import org.apache.commons.lang3.ArrayUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import java.net.SocketTimeoutException;
import java.util.Set;
import java.util.concurrent.TimeUnit;

/**
 * @description: 行驶证三要素
 * @author: xusonglin
 * @create: 2019/7/8 15:19
 * @version: V1.0
 **/
@Service
@Slf4j
public class DrivingLicenseServiceImpl implements DrivingLicenseService {
    @Value("${yh.uri}")
    private String yhUrl;
    @Value("${yh.username}")
    private String yhUserName;
    @Value("${yh.key}")
    private String yhKey;
    @Value("${yh.apiKeyY000f1}")
    private String apiKeyY000f1;
    @Autowired
    private ObjectMapper objectMapper;
    
    private OkHttpClient okHttpClient = new OkHttpClient.Builder().build();

    @Override
    public ChannelTypeHandleResponseObject drivingLicense(HttpServletRequest request, String customBody, int outTime) {
        ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
        ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
        String upstreamCode = Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
        String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);

        if (StringUtils.isBlank(returnType)) {
            returnType = Constant.CUSTOMER_RETURN_ZW;
        }
        if (outTime <= 0) {
            outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
        }
        log.info("drivingLicense---customBody={},outTime={}", customBody, outTime);

        try {
            DrivingLicenseJsonResolveObject jsonResolveObject = objectMapper.readValue(customBody, DrivingLicenseJsonResolveObject.class);
            //参数校验
            if (!validateParams(ret, returnType, jsonResolveObject)) {
                ret.setCode(Constant.SUCCESS);
                request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
                return ret;
            }

            String params = Utils.encrypt(yhKey, jsonResolveObject.toString());
            FormBody.Builder formBodyBuilder = new FormBody.Builder()
                    .add("apiKey", apiKeyY000f1)
                    .add("username", yhUserName)
                    .add("params", params);
            Request okRequest = new Request.Builder()
                    .post(formBodyBuilder.build())
                    .url(yhUrl)
                    .build();
            OkHttpClient client = okHttpClient.newBuilder()
                    .connectTimeout(outTime, TimeUnit.MILLISECONDS)
                    .readTimeout(outTime, TimeUnit.MILLISECONDS)
                    .writeTimeout(outTime, TimeUnit.MILLISECONDS)
                    .build();
            Response response = client.newCall(okRequest).execute();
            String responseContext = "";
            if (response.body() != null) {
                responseContext = response.body().string();
            }
            log.info("supplier10000003.drivingLicense接口responseContext={}", responseContext);

            DrivingLicenseResponseObject responseJsonObject = objectMapper.readValue(responseContext, DrivingLicenseResponseObject.class);
            log.info("supplier10000003.drivingLicense接口responseObject={}", responseJsonObject);

            if (responseJsonObject != null) {
                ret.setCode(Constant.SUCCESS);
                setDrivingLicenseResponse(ret, returnType, responseJsonObject);
                upstreamCode = responseJsonObject.getCode();
                response.close();
            } else {
                ret.setCode(Constant.FAIL);
            }
        } catch (SocketTimeoutException ste) {
            ErrorUtils.captureException(ste);
            log.info("supplier10000003.drivingLicense接口SocketTimeoutException={}", ste);
            ret.setCode(Constant.REQUEST_TIMEOUT);
        } catch (Exception ioe) {
            ErrorUtils.captureException(ioe);
            log.info("supplier10000003.drivingLicense接口Exception={}", ioe);
            ret.setCode(Constant.FAIL);
        }

        //上游返回码
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        return ret;
    }

    private boolean validateParams(ChannelTypeHandleResponseObject ret, String returnType,
                                   DrivingLicenseJsonResolveObject jsonResolveObject) {
        if (!validateParamNullValue(jsonResolveObject)) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
                ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
                ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
                ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
                ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            }
            return false;
        } else if (StringUtils.isBlank(jsonResolveObject.getPlateNumber())
                || !PatternTools.checkResult(Constant.PATTERN_CAR_NUMBER_REGEX, jsonResolveObject.getPlateNumber())) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
                ret.setResultBody(Constant.INVALID_PARAMETER);
                ret.setResultDesc(Constant.INVALID_PARAMETER);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
                ret.setResultBody(Constant.INVALID_PARAMETER);
                ret.setResultDesc(Constant.INVALID_PARAMETER);
            }
            return false;
        } else if (StringUtils.isBlank(jsonResolveObject.getName()) || !PatternTools.checkResult(Constant.PATTERN_CN_NAME_REGEX, jsonResolveObject.getName())) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.NAME_FORMAT_ERROR_CODE);
                ret.setResultBody(Constant.NAME_FORMAT_ERROR);
                ret.setResultDesc(Constant.NAME_FORMAT_ERROR);
            } else {
                ret.setResultCode(Constant.JK_NAME_FORMAT_ERROR_CODE);
                ret.setResultBody(Constant.JK_NAME_FORMAT_ERROR);
                ret.setResultDesc(Constant.JK_NAME_FORMAT_ERROR);
            }
            return false;
        } else if (StringUtils.isBlank(jsonResolveObject.getIdCode()) || !PatternTools.checkResult(Constant.PATTERN_ID_NUMBER_REGEX, jsonResolveObject.getIdCode())) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.IDCODE_FORMAT_ERROR_CODE);
                ret.setResultBody(Constant.IDCODE_FORMAT_ERROR);
                ret.setResultDesc(Constant.IDCODE_FORMAT_ERROR);
            } else {
                ret.setResultCode(Constant.JK_IDCODE_FORMAT_ERROR_CODE);
                ret.setResultBody(Constant.JK_IDCODE_FORMAT_ERROR);
                ret.setResultDesc(Constant.JK_IDCODE_FORMAT_ERROR);
            }
            return false;
        } else {
            return true;
        }
    }

    private void setDrivingLicenseResponse(ChannelTypeHandleResponseObject ret, String returnType,
                                           DrivingLicenseResponseObject responseObject) {
        String responseCode = responseObject.getCode();
        boolean isCharge = !StringUtils.isBlank(responseCode)
                && responseCode.equals(SjjhConstant.RESPONSE_CODE_0)
                && ArrayUtils.contains(SjjhConstant.DRIVING_LICENSE_CHARGE_CODE, responseObject.getData().getResult());
        if (isCharge) {
            ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
        }

        if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
            if (StringUtils.isNotBlank(responseCode) && responseCode.equals(SjjhConstant.RESPONSE_CODE_0)
                    && responseObject.getData().getResult().equals(SjjhConstant.DRIVING_LICENSE_RESULT_CODE_1)) {
                // 一致
                ret.setResultCode(Constant.JK_RETURN_CODE_MATCH);
                ret.setResultBody(JSONObject.toJSONString(responseObject.getData().getResultData()));
                ret.setResultDesc(Constant.MATCH);
            } else if (StringUtils.isNotBlank(responseCode) && responseCode.equals(SjjhConstant.RESPONSE_CODE_0)
                    && responseObject.getData().getResult().equals(SjjhConstant.DRIVING_LICENSE_RESULT_CODE_2)) {
                // 姓名不一致
                ret.setResultCode(Constant.JK_RETURN_CODE_1103);
                ret.setResultBody(Constant.NAME_DISCREPANCY);
                ret.setResultDesc(Constant.NAME_DISCREPANCY);
            } else if (StringUtils.isNotBlank(responseCode) && responseCode.equals(SjjhConstant.RESPONSE_CODE_0)
                    && responseObject.getData().getResult().equals(SjjhConstant.DRIVING_LICENSE_RESULT_CODE_3)) {
                // 身份证未命中
                ret.setResultCode(Constant.JK_RETURN_CODE_1154);
                ret.setResultBody(Constant.UN_MATCH_ID_CODE);
                ret.setResultDesc(Constant.UN_MATCH_ID_CODE);
            } else if (StringUtils.isNotBlank(responseCode) && responseCode.equals(SjjhConstant.RESPONSE_CODE_0)
                    && responseObject.getData().getResult().equals(SjjhConstant.DRIVING_LICENSE_RESULT_CODE_4)) {
                // 车牌号不一致
                ret.setResultCode(Constant.JK_RETURN_CODE_1152);
                ret.setResultBody(Constant.PLATE_NUMBER_DISCREPANCY);
                ret.setResultDesc(Constant.PLATE_NUMBER_DISCREPANCY);
            } else if (StringUtils.isNotBlank(responseCode) && responseCode.equals(SjjhConstant.RESPONSE_CODE_205)) {
                // 参数错误
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
                ret.setResultBody(Constant.INVALID_PARAMETER);
                ret.setResultDesc(Constant.INVALID_PARAMETER);
            } else if (StringUtils.isNotBlank(responseCode) && responseCode.equals(SjjhConstant.RESPONSE_CODE_200)) {
                // 库无
                ret.setResultCode(Constant.JK_RETURN_CODE_NO_INFO);
                ret.setResultBody(Constant.UN_FIND_NUM);
                ret.setResultDesc(Constant.UN_FIND_NUM);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_OTHER_ERROR);
                ret.setResultBody(Constant.OTHER_ERROR);
                ret.setResultDesc(Constant.OTHER_ERROR);
            }
        } else {
            if (StringUtils.isNotBlank(responseCode) && responseCode.equals(SjjhConstant.RESPONSE_CODE_0)
                    && responseObject.getData().getResult().equals(SjjhConstant.DRIVING_LICENSE_RESULT_CODE_1)) {
                // 一致
                ret.setResultCode(Constant.MATCH_CODE);
                ret.setResultBody(JSONObject.toJSONString(responseObject.getData().getResultData()));
                ret.setResultDesc(Constant.MATCH);
            } else if (StringUtils.isNotBlank(responseCode) && responseCode.equals(SjjhConstant.RESPONSE_CODE_0)
                    && responseObject.getData().getResult().equals(SjjhConstant.DRIVING_LICENSE_RESULT_CODE_2)) {
                // 姓名不一致
                ret.setResultCode(Constant.RETURN_CODE_20);
                ret.setResultBody(Constant.NAME_DISCREPANCY);
                ret.setResultDesc(Constant.NAME_DISCREPANCY);
            } else if (StringUtils.isNotBlank(responseCode) && responseCode.equals(SjjhConstant.RESPONSE_CODE_0)
                    && responseObject.getData().getResult().equals(SjjhConstant.DRIVING_LICENSE_RESULT_CODE_3)) {
                // 身份证未命中
                ret.setResultCode(Constant.RETURN_CODE_83);
                ret.setResultBody(Constant.UN_MATCH_ID_CODE);
                ret.setResultDesc(Constant.UN_MATCH_ID_CODE);
            } else if (StringUtils.isNotBlank(responseCode) && responseCode.equals(SjjhConstant.RESPONSE_CODE_0)
                    && responseObject.getData().getResult().equals(SjjhConstant.DRIVING_LICENSE_RESULT_CODE_4)) {
                // 车牌号不一致
                ret.setResultCode(Constant.RETURN_CODE_82);
                ret.setResultBody(Constant.PLATE_NUMBER_DISCREPANCY);
                ret.setResultDesc(Constant.PLATE_NUMBER_DISCREPANCY);
            } else if (StringUtils.isNotBlank(responseCode) && responseCode.equals(SjjhConstant.RESPONSE_CODE_205)) {
                // 参数错误
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
                ret.setResultBody(Constant.INVALID_PARAMETER);
                ret.setResultDesc(Constant.INVALID_PARAMETER);
            } else if (StringUtils.isNotBlank(responseCode) && responseCode.equals(SjjhConstant.RESPONSE_CODE_200)) {
                // 库无
                ret.setResultCode(Constant.UN_FIND_NUM_CODE);
                ret.setResultBody(Constant.UN_FIND_NUM);
                ret.setResultDesc(Constant.UN_FIND_NUM);
            } else {
                ret.setResultCode(Constant.OTHER_ERROR_CODE);
                ret.setResultBody(Constant.OTHER_ERROR);
                ret.setResultDesc(Constant.OTHER_ERROR);
            }

        }
    }

    private boolean validateParamNullValue(DrivingLicenseJsonResolveObject jsonResolveObject) {
        ValidatorFactory vf = Validation.buildDefaultValidatorFactory();
        Validator validator = vf.getValidator();
        Set<ConstraintViolation<DrivingLicenseJsonResolveObject>> set = validator.validate(jsonResolveObject);
        for (ConstraintViolation<DrivingLicenseJsonResolveObject> con : set) {
            if (StringUtils.isNotBlank(con.getMessage())) {
                return false;
            }
        }
        return true;
    }
}
