package info.aspirecn.rdc.iov.sjjh.servicenode.supplier.yh.service.impl;

import com.fasterxml.jackson.core.JsonParseException;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.JsonMappingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.exc.UnrecognizedPropertyException;
import com.google.common.base.Preconditions;
import info.aspirecn.iov.sjjh.commons.lang.ChannelTypeHandleResponseObject;
import info.aspirecn.iov.sjjh.commons.lang.Constant;
import info.aspirecn.iov.sjjh.commons.lang.PatternTools;
import info.aspirecn.rdc.aspirecloud.node.except.utils.ErrorUtils;
import info.aspirecn.rdc.iov.sjjh.servicenode.supplier.yh.constant.SjjhConstant;
import info.aspirecn.rdc.iov.sjjh.servicenode.supplier.yh.service.YHChannelService;
import info.aspirecn.rdc.iov.sjjh.servicenode.supplier.yh.utils.*;
import info.aspirecn.rdc.iov.sjjh.servicenode.supplier.yh.vo.*;
import info.aspirecn.rdc.iov.sjjh.servicenode.supplier.yh_interface.vo.CustomBodyObject;
import lombok.NonNull;
import lombok.extern.slf4j.Slf4j;
import net.logstash.logback.encoder.org.apache.commons.lang.math.NumberUtils;
import okhttp3.*;

import org.apache.commons.lang3.ArrayUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import javax.servlet.http.HttpServletRequest;
import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import java.io.IOException;
import java.net.SocketTimeoutException;
import java.util.Set;
import java.util.concurrent.TimeUnit;

/**
 * @Auther jianggang
 * @Date 2018/10/25 15:55:49
 * @Description
 */

@Service
@Slf4j
public class YHChannelServiceImpl implements YHChannelService {
	@Value("${yh.uri}")
	private String yhUrl;
	@Value("${yh.username}")
    private String yhUserName;
	@Value("${yh.key}")
    private String yhKey;
	@Value("${yh.apiKeyY000x1}")
    private String yhApiKeyY000x1;
	@Value("${yh.apiKeyY000w1}")
    private String yhApiKeyY000w1;
	@Value("${yh.apiKeyY001c1}")
    private String yhApiKeyY001c1;
	@Value("${yh.apiKeyY001b1}")
    private String yhApiKeyY001b1;
	@Value("${yh.apiKeyY000c1}")
    private String checkCMCCOnlineStatusApiKey;
    @Value("${yh.apiKeyY000b1}")
    private String checkCMCCOnlineTimeApiKey;
    @Value("${yh.apiKeyY001w1}")
    private String yhApiKeyY001w1;
    @Value("${yh.apiKeyY001x1}")
    private String yhApiKeyY001x1;
    @Value("${yh.apiKeyY002y1}")
    private String yhApiKeyY002y1;

    @Autowired
    private SupplierProperties supplierProperties;

	@Autowired
	private LocationSupplierProperties locationSupplierProperties;
	@Autowired
	private LocationUtil locationUtil;
    private static final ConnectionPool POOL = new ConnectionPool(4000,
            5, TimeUnit.MINUTES);
    
    private OkHttpClient okHttpClient = new OkHttpClient.Builder().build();

    @Override
    public ChannelTypeHandleResponseObject sendTwoParamIdCardRequest(String channelId, @NonNull Integer outTime, String customBody) {
    	ServletRequestAttributes servletRequestAttributes = (ServletRequestAttributes)RequestContextHolder.getRequestAttributes();
        HttpServletRequest httpRequest = servletRequestAttributes.getRequest();
    	OkHttpClient okHttpClient = null;

        ChannelTypeHandleResponseObject handleResponseObject = new ChannelTypeHandleResponseObject();
        String upstreamCode = Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
        try {

            Preconditions.checkNotNull(channelId,"通道id为空");
            Preconditions.checkNotNull(customBody,"请求json字符串为空");

            ObjectMapper objectMapper = new ObjectMapper();
            CustomBodyObject customBodyObject = objectMapper.readValue(
                    customBody,CustomBodyObject.class);
            int code =  checkCustomeBody(customBodyObject);
  	       if(code != 0 ){
  	    	 handleResponseObject.setCode(Constant.SUCCESS);
  	    	 handleResponseObject.setResultCode(code);
  	    	 return handleResponseObject;
  	       }

            if(outTime <= 0){
                outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
            }
            okHttpClient =new OkHttpClient.Builder()
                    .connectTimeout(outTime,TimeUnit.MILLISECONDS)
                    .readTimeout(outTime,TimeUnit.MILLISECONDS)
                    .writeTimeout(outTime,TimeUnit.MILLISECONDS)
                    .connectionPool(POOL)
                    .build();

            String params = Utils.desEncrypt("name="+customBodyObject.getName()+"&identityCard="+customBodyObject.getIdCode());
            String requestStr = "apiKey="+supplierProperties.getApiKey()+"&username="+supplierProperties.getUsername()+"&params="+params;
            RequestBody requestBody = RequestBody.create(MediaType.parse("application/x-www-form-urlencoded"),requestStr);
            Request request = new Request.Builder()
                    .url(supplierProperties.getUrl())
                    .post(requestBody)
                    .build();
            Response response = okHttpClient.newCall(request).execute();
            handleResponseObject = handleResponse( response);
        }catch (SocketTimeoutException e){
            log.error("SocketTimeoutException message:{}",e);
            ErrorUtils.captureException(e);
            handleResponseObject.setCode(Constant.REQUEST_TIMEOUT);
            handleResponseObject.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
            return handleResponseObject;
        }catch(UnrecognizedPropertyException upe) {
			log.info("yh-UnrecognizedPropertyException：{}", upe);
            ErrorUtils.captureException(upe);
            handleResponseObject.setCode(Constant.SUCCESS);
            handleResponseObject.setIsCharge(Constant.IS_NOT_CHARGE);
            /**参数错误*/
            if(Constant.CUSTOMER_RETURN_JK.equals("1")){
            	handleResponseObject.setResultCode(Constant.JK_RETURN_CODE_9909);
            }else{
            	handleResponseObject.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            handleResponseObject.setResultBody(Constant.PARAMETER_NAME_ERROR);
            handleResponseObject.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            return handleResponseObject;
		}catch (Exception e){
            log.error("Exception message:{}",e);
            ErrorUtils.captureException(e);
            handleResponseObject.setCode(Constant.FAIL);
            handleResponseObject.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
            return handleResponseObject;
        }
        httpRequest.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        return handleResponseObject;
    }
    ChannelTypeHandleResponseObject handleResponse(Response response) throws JsonParseException, JsonMappingException, IOException {
    	ChannelTypeHandleResponseObject handleResponseObject = new ChannelTypeHandleResponseObject();
	   TwoParamIdCardResponseObject responseObject = new TwoParamIdCardResponseObject();
    	if(response.isSuccessful()){
    		ObjectMapper objectMapper = new ObjectMapper();
        	responseObject = objectMapper.readValue(response.body().string(),TwoParamIdCardResponseObject.class);
        	int channelResponseCode = 0;
        	String responsebody="";
        	String upstreamCode = responseObject.getCode();
        	if ("0".equals(upstreamCode)) {
				String state = responseObject.getData().getCompStatus();
				if ("1".equals(state)) {
					channelResponseCode = 1;
					responsebody = Constant.MATCH;
				} else if ("2".equals(state)) {
					channelResponseCode = 2;
					responsebody = Constant.UN_MATCH;
				} else if ("3".equals(state)) {
					channelResponseCode = 4;
					responsebody = Constant.UN_FIND_NUM;
				}
			} else if ("205".equals(upstreamCode)) {
				channelResponseCode = 8;
				responsebody = Constant.INVALID_PARAMETER;
			} else if ("200".equals(upstreamCode)) {
				channelResponseCode = 2;
				responsebody = Constant.UN_MATCH;
			} else {
				channelResponseCode = 3;
				responsebody = Constant.OTHER_ERROR;
			}
        	handleResponseObject.setCode(1);
        	handleResponseObject.setResultCode(channelResponseCode);
        	handleResponseObject.setResultBody(responsebody);
        	if("0".equals(responseObject.getCode()) &&
                     ("1".equals(responseObject.getData().getCompStatus())
                             ||"2".equals(responseObject.getData().getCompStatus()))){
        		handleResponseObject.setIsCharge(Constant.INTERFACE_QUERY_FEE);
             }else{
            	 handleResponseObject.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
             }
        }else{
        	log.error("供应商http状态码不正确,httpStatus:{}",response.code());
        	throw new SocketTimeoutException();
        }
    	return handleResponseObject;
    }

    @Override
	public ChannelTypeHandleResponseObject checkLocation(HttpServletRequest request,  String customBody,
			int outTime) {
		ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
		ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
		String upstreamCode = Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
		try {
			if (outTime <= 0) {
				outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
			}

			log.info("checkLocation---customBody={},outTime={}", customBody, outTime);
			ObjectMapper objectMapper = new ObjectMapper();
			LocationRequestObject requestObject = objectMapper.readValue(customBody, LocationRequestObject.class);


			// 校验参数
			boolean bool = locationUtil.checkLocationParm(requestObject);
			if (bool) {
				ret.setCode(Constant.SUCCESS);
				ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
				ret.setResultBody("参数错误");
				return ret;
			}
			if(!StringUtils.isBlank(requestObject.getPhone()) && !PatternTools.checkResult(Constant.PATTERN_MOBILE_REGEX, requestObject.getPhone())){
		        ret.setCode(Constant.SUCCESS);
				ret.setResultCode(Constant.MOBILE_FORMAT_ERROR_CODE);
				ret.setResultBody("参数错误");
				return ret;
		    }
			//计算params
			String params = locationUtil.calculateParam(requestObject);
			String apiKey =locationSupplierProperties.getApiKey();
			String username= locationSupplierProperties.getUsername();
			String url = locationSupplierProperties.getUrl();
			log.info("位置校验接口时传的参数,apiKey:{},username:{},url:{}", apiKey,username,url);


			RequestBody body = new FormBody.Builder().add("apiKey",apiKey).add("username",username).add("params", params).build();
			Request okRequest = new Request.Builder().post(body).url(url).build();
			Response response = getResponse( okRequest, outTime);
			if(response.code()==200){
				String responseContext = response.body().string();
				log.info("位置校验接口后的返回:{}", responseContext);
				LocationCheckQuestResponseObject responseObject = objectMapper.readValue(responseContext,
						LocationCheckQuestResponseObject.class);
				if (responseObject != null) {
					upstreamCode = responseObject.getCode();
					// code等0且isMatch等于1时收费
					locationUtil.locationCodeCheck(ret,responseObject);
				}
			}else{
				log.error("位置校验返回httpCode:{}",response.code());
				throw new Exception("位置校验返回httpCode:"+response.code());
			}

		} catch (SocketTimeoutException ste) {
			ErrorUtils.captureException(ste);
			ret.setCode(Constant.REQUEST_TIMEOUT);

		} catch(UnrecognizedPropertyException upe) {
			log.info("yh.位置校验-UnrecognizedPropertyException：{}", upe);
            ErrorUtils.captureException(upe);
            ret.setCode(Constant.SUCCESS);
            ret.setIsCharge(Constant.IS_NOT_CHARGE);
            /**参数错误*/
            if(Constant.CUSTOMER_RETURN_JK.equals("1")){
            	ret.setResultCode(Constant.JK_RETURN_CODE_9909);
            }else{
            	ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
            ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            return ret;
		} catch (Exception ioe) {
			ErrorUtils.captureException(ioe);
			ret.setCode(Constant.FAIL);

		}

		request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
		return ret;
	}
    public int checkCustomeBody(CustomBodyObject customBodyObject){
    	String name = customBodyObject.getName();
    	String idCode = customBodyObject.getIdCode();
    	if(StringUtils.isBlank(name) || !PatternTools.checkResult(Constant.PATTERN_CN_NAME_REGEX, name)){
	        return Constant.NAME_FORMAT_ERROR_CODE;
	    }
	    if(StringUtils.isBlank(idCode) || 	!PatternTools.checkResult(Constant.PATTERN_ID_NUMBER_REGEX, idCode)){
	        return Constant.IDCODE_FORMAT_ERROR_CODE;
	    }
	    return 0;
    }

    @Override
    public ChannelTypeHandleResponseObject yhDianXinCheck(HttpServletRequest request,
    		String customBody,int outTime) {
    	ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
    	ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
    	String upstreamCode = Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
    	String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
    	if(StringUtils.isBlank(returnType)) {
    		returnType = Constant.CUSTOMER_RETURN_ZW;
    	}
    	try {
    		if(outTime <= 0) {
                outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
	        }

    		log.info("yhDianXinCheck---customBody={},outTime={}",customBody,outTime);
    		ObjectMapper objectMapper = new ObjectMapper();
    		ThreeCheckRequestObject requestObject = objectMapper.readValue(customBody,
    				ThreeCheckRequestObject.class);
	    	String name = requestObject.getName();
	        String idCode = requestObject.getIdCode();
	        String mobile = requestObject.getMobile();
	        //校验参数
	        ret = returnISPThreeCheckPara( name, idCode, mobile, returnType);
	        if(StringUtils.isNotBlank(ret.getResultDesc())) {
	        	return ret;
	        }

	        String params = Utils.encrypt(yhKey, "name="+ name + "&identityCard=" + idCode + "&phone=" + mobile);
	        String requestUrl = yhUrl + "?apiKey="+yhApiKeyY000x1+"&username="+yhUserName+"&format=json&params="+params;

			MediaType mediaType = MediaType.parse(org.springframework.http.MediaType.APPLICATION_JSON_UTF8_VALUE);
	        RequestBody requestBody = RequestBody.create(mediaType, "");

	        Request okRequest = new Request.Builder().post(requestBody).url(requestUrl).build();
	        Response response = getResponse( okRequest, outTime);
	        String responseContext = response.body().string();
	    	log.info("yhDianXinCheck调接口后的返回:{}", responseContext);

	    	DianXinThreeCheckResponseObject responseObject = objectMapper.readValue(responseContext,
	    			DianXinThreeCheckResponseObject.class);

	    	if(responseObject != null) {
	    		upstreamCode = responseObject.getCode();

	    		//code等200且data等于0或1时收费
	    		boolean resultBool = SjjhConstant.RESPONSE_CODE_0.equals(responseObject.getCode())
	    				&& (SjjhConstant.DIAN_XIN_RESULT_VALUE_T.equals(responseObject.getData().getResult())
						|| SjjhConstant.DIAN_XIN_RESULT_VALUE_F.equals(responseObject.getData().getResult()));
	    		if(resultBool) {
	    	        ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
	    		}
	    		ret.setCode(Constant.SUCCESS);

	    		//根据客户来源返回对应码
	    		getDianXinThreeCheckChannelTypeHandleResponseObject(returnType, ret, responseObject);

	    	}
	    } catch(SocketTimeoutException ste) {
	    	ErrorUtils.captureException(ste);
	    	ret.setCode(Constant.REQUEST_TIMEOUT);

	    } catch(UnrecognizedPropertyException upe) {
			log.info("yhDianXinCheck Exception：{}", upe);
            ErrorUtils.captureException(upe);
            ret.setCode(Constant.SUCCESS);
            ret.setIsCharge(Constant.IS_NOT_CHARGE);
            /**参数错误*/
            if(Constant.CUSTOMER_RETURN_JK.equals(returnType)){
            	ret.setResultCode(Constant.JK_RETURN_CODE_9909);
            }else{
            	ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
            ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            return ret;
		} catch(Exception ioe) {
	    	ErrorUtils.captureException(ioe);
	    	ret.setCode(Constant.FAIL);

	    }

    	request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
    	return ret;
    }

    @Override
    public ChannelTypeHandleResponseObject yhLianTongCheck(HttpServletRequest request,
    		String customBody,int outTime) {
    	ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
    	ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
    	String upstreamCode = Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
    	String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
    	if(StringUtils.isBlank(returnType)) {
    		returnType = Constant.CUSTOMER_RETURN_ZW;
    	}

    	try {
    		if(outTime <= 0) {
	        	outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
	        }


    		log.info("yhLianTongCheck---customBody={},outTime={}",customBody,outTime);
    		ObjectMapper objectMapper = new ObjectMapper();
    		ThreeCheckRequestObject requestObject = objectMapper.readValue(customBody,
    				ThreeCheckRequestObject.class);
	    	String name = requestObject.getName();
	        String idCode = requestObject.getIdCode();
	        String mobile = requestObject.getMobile();
	        //校验参数
	        ret = returnISPThreeCheckPara( name, idCode, mobile, returnType);
	        if(StringUtils.isNotBlank(ret.getResultDesc())) {
	        	return ret;
	        }

	        String params = Utils.encrypt(yhKey, "name="+ name + "&identityCard=" + idCode + "&phone=" + mobile);
	        String requestUrl = yhUrl + "?apiKey="+yhApiKeyY000w1+"&username="+yhUserName+"&format=json&params="+params;

			MediaType mediaType = MediaType.parse(org.springframework.http.MediaType.APPLICATION_JSON_UTF8_VALUE);
	        RequestBody requestBody = RequestBody.create(mediaType, "");

	        Request okRequest = new Request.Builder().post(requestBody).url(requestUrl).build();
	        Response response = getResponse( okRequest, outTime);
	        String responseContext = response.body().string();
	    	log.info("yhLianTongCheck调接口后的返回:{}", responseContext);

	    	LianTongThreeCheckResponseObject responseObject = objectMapper.readValue(responseContext,
	    			LianTongThreeCheckResponseObject.class);

	    	if(responseObject != null) {
	    		upstreamCode = responseObject.getCode();

	    		//code等200或 等0且data的status等1且status的checkResult等于00或01或02或03时收费
	    		boolean resultBool = SjjhConstant.RESPONSE_CODE_200.equals(responseObject.getCode()) ||
	    				(SjjhConstant.RESPONSE_CODE_0.equals(responseObject.getCode())
		    				&& responseObject.getData() != null
		    				&& SjjhConstant.RESPONSE_STATE_1.equals(responseObject.getData().getStatus())
		    				&& (SjjhConstant.RESPONSE_CHECK_RESULT_00.equals(responseObject.getData().getCheckResult())
							|| SjjhConstant.RESPONSE_CHECK_RESULT_01.equals(responseObject.getData().getCheckResult())
							|| SjjhConstant.RESPONSE_CHECK_RESULT_02.equals(responseObject.getData().getCheckResult())
							|| SjjhConstant.RESPONSE_CHECK_RESULT_03.equals(responseObject.getData().getCheckResult())));
	    		if(resultBool) {
	    	        ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
	    		}
	    		ret.setCode(Constant.SUCCESS);

	    		//根据客户来源返回对应码
	    		ret = getLianTongThreeCheckChannelTypeHandleResponseObject(returnType, ret, responseObject);

	    	}
	    } catch(SocketTimeoutException ste) {
	    	ErrorUtils.captureException(ste);
	    	ret.setCode(Constant.REQUEST_TIMEOUT);

	    } catch(UnrecognizedPropertyException upe) {
			log.info("yhLianTongCheck Exception：{}", upe);
            ErrorUtils.captureException(upe);
            ret.setCode(Constant.SUCCESS);
            ret.setIsCharge(Constant.IS_NOT_CHARGE);
            /**参数错误*/
            if(Constant.CUSTOMER_RETURN_JK.equals(returnType)){
            	ret.setResultCode(Constant.JK_RETURN_CODE_9909);
            }else{
            	ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
            ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            return ret;
		} catch(Exception ioe) {
	    	ErrorUtils.captureException(ioe);
	    	ret.setCode(Constant.FAIL);

	    }

    	request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
    	return ret;
    }

    /**
     * 运行商三要素参数校验
     * @param name
     * @param idCode
     * @param mobile
     * @return
     */
    private ChannelTypeHandleResponseObject returnISPThreeCheckPara(String name,
    		String idCode,String mobile,String returnType) {
    	ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();

    	if(StringUtils.isBlank(name) || !PatternTools.checkResult(Constant.PATTERN_CN_NAME_REGEX, name)) {
        	ret.setCode(Constant.SUCCESS);
        	if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
        		ret.setResultCode(Constant.NAME_FORMAT_ERROR_CODE);
        		ret.setResultDesc(Constant.NAME_FORMAT_ERROR);
        		ret.setResultBody(Constant.NAME_FORMAT_ERROR);
        	} else {
        		ret.setResultCode(Constant.JK_NAME_FORMAT_ERROR_CODE);
        		ret.setResultDesc(Constant.JK_NAME_FORMAT_ERROR);
        		ret.setResultBody(Constant.JK_NAME_FORMAT_ERROR);
        	}

        } else if(StringUtils.isBlank(idCode) || !PatternTools.checkResult(Constant.PATTERN_ID_NUMBER_REGEX, idCode)) {
        	ret.setCode(Constant.SUCCESS);
        	if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
        		ret.setResultCode(Constant.IDCODE_FORMAT_ERROR_CODE);
        		ret.setResultDesc(Constant.IDCODE_FORMAT_ERROR);
        		ret.setResultBody(Constant.IDCODE_FORMAT_ERROR);
        	} else {
        		ret.setResultCode(Constant.JK_IDCODE_FORMAT_ERROR_CODE);
        		ret.setResultDesc(Constant.JK_IDCODE_FORMAT_ERROR);
        		ret.setResultBody(Constant.JK_IDCODE_FORMAT_ERROR);
        	}

        }  else if(StringUtils.isBlank(mobile) || !PatternTools.checkResult(Constant.PATTERN_MOBILE_REGEX, mobile)) {
        	ret.setCode(Constant.SUCCESS);
        	if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
        		ret.setResultCode(Constant.MOBILE_FORMAT_ERROR_CODE);
        		ret.setResultDesc(Constant.MOBILE_FORMAT_ERROR);
        		ret.setResultBody(Constant.MOBILE_FORMAT_ERROR);
        	} else {
        		ret.setResultCode(Constant.JK_MOBILE_FORMAT_ERROR_CODE);
        		ret.setResultDesc(Constant.JK_MOBILE_FORMAT_ERROR);
        		ret.setResultBody(Constant.JK_MOBILE_FORMAT_ERROR);
        	}

        }

    	return ret;
    }

    /**
     * 根据客户不同，返回电信三要素对应码
     * @param returnType
     * @param ret
     * @param responseObject
     * @return
     */
    private ChannelTypeHandleResponseObject getDianXinThreeCheckChannelTypeHandleResponseObject(
    		String returnType,
    		ChannelTypeHandleResponseObject ret,
    		DianXinThreeCheckResponseObject responseObject) {
    	if(SjjhConstant.RESPONSE_CODE_0.equals(responseObject.getCode())
				&& SjjhConstant.DIAN_XIN_RESULT_VALUE_T.equals(responseObject.getData().getResult())) {
			//匹配
    		if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
    			ret.setResultCode(Constant.JK_RETURN_CODE_MATCH);
    		} else {
    			ret.setResultCode(Constant.MATCH_CODE);
    		}
			ret.setResultBody(Constant.MATCH);
			ret.setResultDesc(Constant.MATCH);
		} else if(SjjhConstant.RESPONSE_CODE_0.equals(responseObject.getCode())
				&& SjjhConstant.DIAN_XIN_RESULT_VALUE_F.equals(responseObject.getData().getResult())) {
			//不匹配
			if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
				ret.setResultCode(Constant.JK_RETURN_CODE_NO_MATCH);
			} else {
    			ret.setResultCode(Constant.UN_MATCH_CODE);
    		}
			ret.setResultBody(Constant.UN_MATCH);
			ret.setResultDesc(Constant.UN_MATCH);
		} else if(SjjhConstant.RESPONSE_CODE_200.equals(responseObject.getCode())) {
			//未找到
			if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
				ret.setResultCode(Constant.JK_RETURN_CODE_NO_INFO);
			} else {
				ret.setResultCode(Constant.UN_FIND_NUM_CODE);
			}
			ret.setResultBody(Constant.UN_FIND_NUM);
			ret.setResultDesc(Constant.UN_FIND_NUM);
		} else if(SjjhConstant.RESPONSE_CODE_908.equals(responseObject.getCode())) {
			//号段不对
			if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
				ret.setResultCode(Constant.JK_RETURN_CODE_NUMBER_UNMATCH);
			} else {
				ret.setResultCode(Constant.PARAGRAPH_NUMBER_UNMATCH_CODE);
			}
			ret.setResultBody(Constant.PARAGRAPH_NUMBER_UNMATCH);
			ret.setResultDesc(Constant.PARAGRAPH_NUMBER_UNMATCH);
		}  else if(SjjhConstant.RESPONSE_CODE_205.equals(responseObject.getCode())) {
			//参数错误
			if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
				ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
			} else {
				ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
			}
			ret.setResultBody(Constant.INVALID_PARAMETER);
			ret.setResultDesc(Constant.INVALID_PARAMETER);
		} else if(SjjhConstant.RESPONSE_CODE_207.equals(responseObject.getCode())) {
			//手机号码错误
			if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
				ret.setResultCode(Constant.JK_MOBILE_FORMAT_ERROR_CODE);
				ret.setResultBody(Constant.JK_MOBILE_FORMAT_ERROR);
				ret.setResultDesc(Constant.JK_MOBILE_FORMAT_ERROR);
			} else {
				ret.setResultCode(Constant.MOBILE_FORMAT_ERROR_CODE);
				ret.setResultBody(Constant.MOBILE_FORMAT_ERROR);
				ret.setResultDesc(Constant.MOBILE_FORMAT_ERROR);
			}

		}else {
			//其他错误
			if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
				ret.setResultCode(Constant.JK_RETURN_CODE_OTHER_ERROR);
			} else {
				ret.setResultCode(Constant.OTHER_ERROR_CODE);
			}
			ret.setResultBody(Constant.OTHER_ERROR);
			ret.setResultDesc(Constant.OTHER_ERROR);
		}


    	return ret;
    }

    /**
     * 根据客户不同，返回联通三要素对应码
     * @param returnType
     * @param ret
     * @param responseObject
     * @return
     */
    private ChannelTypeHandleResponseObject getLianTongThreeCheckChannelTypeHandleResponseObject(
    		String returnType,
    		ChannelTypeHandleResponseObject ret,
    		LianTongThreeCheckResponseObject responseObject) {
    	boolean bool = SjjhConstant.RESPONSE_CODE_0.equals(responseObject.getCode())
    			&& responseObject.getData() != null
				&& SjjhConstant.RESPONSE_STATE_1.equals(responseObject.getData().getStatus());
    	if(bool	&& SjjhConstant.RESPONSE_CHECK_RESULT_00.equals(responseObject.getData().getCheckResult())) {
			//匹配
    		if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
    			ret.setResultCode(Constant.JK_RETURN_CODE_MATCH);
    		} else {
    			ret.setResultCode(Constant.MATCH_CODE);
    		}
			ret.setResultBody(Constant.MATCH);
			ret.setResultDesc(Constant.MATCH);
		} else if(bool && SjjhConstant.RESPONSE_CHECK_RESULT_01.equals(responseObject.getData().getCheckResult())) {
			//手机号一致，证件号和姓名不一致
			if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
				ret.setResultCode(Constant.JK_RETURN_CODE_1140);
			} else {
    			ret.setResultCode(Constant.RETURN_CODE_37);
    		}
			ret.setResultBody(SjjhConstant.RETURN_CODE_37_TEXT);
			ret.setResultDesc(SjjhConstant.RETURN_CODE_37_TEXT);
		}  else if(bool && SjjhConstant.RESPONSE_CHECK_RESULT_02.equals(responseObject.getData().getCheckResult())) {
			//手机号和证件号一致，姓名不一致
			if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
				ret.setResultCode(Constant.JK_RETURN_CODE_1141);
			} else {
    			ret.setResultCode(Constant.RETURN_CODE_38);
    		}
			ret.setResultBody(SjjhConstant.RETURN_CODE_38_TEXT);
			ret.setResultDesc(SjjhConstant.RETURN_CODE_38_TEXT);
		}  else if(bool && SjjhConstant.RESPONSE_CHECK_RESULT_03.equals(responseObject.getData().getCheckResult())) {
			//手机号和姓名一致，证件号不一致
			if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
				ret.setResultCode(Constant.JK_RETURN_CODE_1142);
			} else {
    			ret.setResultCode(Constant.RETURN_CODE_39);
    		}
			ret.setResultBody(SjjhConstant.RETURN_CODE_39_TEXT);
			ret.setResultDesc(SjjhConstant.RETURN_CODE_39_TEXT);
		} else if(SjjhConstant.RESPONSE_CODE_200.equals(responseObject.getCode())) {
			//未找到
			if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
				ret.setResultCode(Constant.JK_RETURN_CODE_NO_INFO);
			} else {
				ret.setResultCode(Constant.UN_FIND_NUM_CODE);
			}
			ret.setResultBody(Constant.UN_FIND_NUM);
			ret.setResultDesc(Constant.UN_FIND_NUM);
		} else if(SjjhConstant.RESPONSE_CODE_908.equals(responseObject.getCode())) {
			//号段不对
			if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
				ret.setResultCode(Constant.JK_RETURN_CODE_NUMBER_UNMATCH);
			} else {
				ret.setResultCode(Constant.PARAGRAPH_NUMBER_UNMATCH_CODE);
			}
			ret.setResultBody(Constant.PARAGRAPH_NUMBER_UNMATCH);
			ret.setResultDesc(Constant.PARAGRAPH_NUMBER_UNMATCH);
		}  else if(SjjhConstant.RESPONSE_CODE_205.equals(responseObject.getCode())) {
			//参数错误
			if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
				ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
			} else {
				ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
			}
			ret.setResultBody(Constant.INVALID_PARAMETER);
			ret.setResultDesc(Constant.INVALID_PARAMETER);
		} else if(SjjhConstant.RESPONSE_CODE_207.equals(responseObject.getCode())) {
			//手机号码错误
			if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
				ret.setResultCode(Constant.JK_MOBILE_FORMAT_ERROR_CODE);
				ret.setResultBody(Constant.JK_MOBILE_FORMAT_ERROR);
				ret.setResultDesc(Constant.JK_MOBILE_FORMAT_ERROR);
			} else {
				ret.setResultCode(Constant.MOBILE_FORMAT_ERROR_CODE);
				ret.setResultBody(Constant.MOBILE_FORMAT_ERROR);
				ret.setResultDesc(Constant.MOBILE_FORMAT_ERROR);
			}

		}else {
			//其他错误
			if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
				ret.setResultCode(Constant.JK_RETURN_CODE_OTHER_ERROR);
			} else {
				ret.setResultCode(Constant.OTHER_ERROR_CODE);
			}
			ret.setResultBody(Constant.OTHER_ERROR);
			ret.setResultDesc(Constant.OTHER_ERROR);
		}


    	return ret;
    }


    @Override
	public ChannelTypeHandleResponseObject yhLianTongOnlineTimeCheck(
			HttpServletRequest request,String customBody,int outTime) {
    	ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
    	ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
    	String upstreamCode = Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
    	String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
    	if(StringUtils.isBlank(returnType)) {
    		returnType = Constant.CUSTOMER_RETURN_ZW;
    	}

    	try {
    		if(outTime <= 0) {
	        	outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
	        }  		

    		log.info("yhLianTongOnlineTimeCheck---customBody={},outTime={}",customBody,outTime);
    		ObjectMapper objectMapper = new ObjectMapper();
    		LianTongOnlineJsonObject jsonObject = objectMapper.readValue(customBody,
    				LianTongOnlineJsonObject.class);
	        String mobile = jsonObject.getMobile();
	        //校验参数
	        ret = returnMobieCheckPara( mobile, returnType);
	        if(StringUtils.isNotBlank(ret.getResultDesc())) {
	        	return ret;
	        }

	        String params = Utils.encrypt(yhKey, "phone=" + mobile);
	        String requestUrl = yhUrl + "?apiKey="+yhApiKeyY001b1+"&username="+yhUserName+"&format=json&params="+params;

			MediaType mediaType = MediaType.parse(org.springframework.http.MediaType.APPLICATION_JSON_UTF8_VALUE);
	        RequestBody requestBody = RequestBody.create(mediaType, "");

	        Request okRequest = new Request.Builder().post(requestBody).url(requestUrl).build();
	        Response response = getResponse( okRequest, outTime);
	        String responseContext = response.body().string();
	    	log.info("yhLianTongOnlineTimeCheck调接口后的返回:{}", responseContext);

	    	LianTongOnlineCheckResponseObject responseObject = objectMapper.readValue(responseContext,
	    			LianTongOnlineCheckResponseObject.class);

	    	if(responseObject != null) {
	    		upstreamCode = responseObject.getCode();

	    		//code等200或 等0且data的status等1且status的checkResult等于00或01或02或03时收费
	    		boolean resultBool = SjjhConstant.RESPONSE_CODE_200.equals(responseObject.getCode()) ||
	    				(SjjhConstant.RESPONSE_CODE_0.equals(responseObject.getCode())
		    				&& responseObject.getData() != null
		    				&& SjjhConstant.RESPONSE_STATE_1.equals(responseObject.getData().getStatus())
		    				&& (SjjhConstant.RESPONSE_STATE_1.equals(responseObject.getData().getResult())
							|| SjjhConstant.RESPONSE_STATE_2.equals(responseObject.getData().getResult())
							|| SjjhConstant.RESPONSE_STATE_3.equals(responseObject.getData().getResult())
							|| SjjhConstant.RESPONSE_STATE_4.equals(responseObject.getData().getResult())
		    				|| SjjhConstant.RESPONSE_STATE_5.equals(responseObject.getData().getResult())
	    					|| SjjhConstant.RESPONSE_STATE_6.equals(responseObject.getData().getResult())
							|| SjjhConstant.RESPONSE_STATE_7.equals(responseObject.getData().getResult())));
	    		if(resultBool) {
	    	        ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
	    		}
	    		ret.setCode(Constant.SUCCESS);

	    		//根据客户来源返回对应码
	    		getOnlineTimeCode( ret, responseObject, returnType);

	    	}
	    } catch(SocketTimeoutException ste) {
	    	ErrorUtils.captureException(ste);
	    	ret.setCode(Constant.REQUEST_TIMEOUT);

	    } catch(UnrecognizedPropertyException upe) {
			log.info("yhLianTongOnlineTimeCheck-UnrecognizedPropertyException：{}", upe);
            ErrorUtils.captureException(upe);
            ret.setCode(Constant.SUCCESS);
            ret.setIsCharge(Constant.IS_NOT_CHARGE);
            /**参数错误*/
            if(Constant.CUSTOMER_RETURN_JK.equals(returnType)){
            	ret.setResultCode(Constant.JK_RETURN_CODE_9909);
            }else{
            	ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
        	ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            return ret;
		} catch(Exception ioe) {
	    	ErrorUtils.captureException(ioe);
	    	ret.setCode(Constant.FAIL);

	    }

    	request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
    	return ret;
    }

    @Override
	public ChannelTypeHandleResponseObject yhLianTongOnlineStatusCheck(
			HttpServletRequest request,String customBody,int outTime) {
    	ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
    	ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
    	String upstreamCode = Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
    	String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
    	if(StringUtils.isBlank(returnType)) {
    		returnType = Constant.CUSTOMER_RETURN_ZW;
    	}

    	try {
    		if(outTime <= 0) {
	        	outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
	        }


    		log.info("yhLianTongOnlineStatusCheck---customBody={},outTime={}",customBody,outTime);
    		ObjectMapper objectMapper = new ObjectMapper();
    		LianTongOnlineJsonObject jsonObject = objectMapper.readValue(customBody,
    				LianTongOnlineJsonObject.class);
	        String mobile = jsonObject.getMobile();
	        //校验参数
	        ret = returnMobieCheckPara( mobile, returnType);
	        if(StringUtils.isNotBlank(ret.getResultDesc())) {
	        	return ret;
	        }

	        String params = Utils.encrypt(yhKey, "phone=" + mobile);
	        String requestUrl = yhUrl + "?apiKey="+yhApiKeyY001c1+"&username="+yhUserName+"&format=json&params="+params;

			MediaType mediaType = MediaType.parse(org.springframework.http.MediaType.APPLICATION_JSON_UTF8_VALUE);
	        RequestBody requestBody = RequestBody.create(mediaType, "");

	        Request okRequest = new Request.Builder().post(requestBody).url(requestUrl).build();
	        Response response = getResponse( okRequest, outTime);
	        String responseContext = response.body().string();
	    	log.info("yhLianTongOnlineStatusCheck调接口后的返回:{}", responseContext);

	    	LianTongOnlineCheckResponseObject responseObject = objectMapper.readValue(responseContext,
	    			LianTongOnlineCheckResponseObject.class);

	    	if(responseObject != null) {
	    		upstreamCode = responseObject.getCode();

	    		//code等200或 等0且data的status等1且status的checkResult等于00或01或02或03时收费
	    		boolean resultBool = SjjhConstant.RESPONSE_CODE_200.equals(responseObject.getCode()) ||
	    				(SjjhConstant.RESPONSE_CODE_0.equals(responseObject.getCode())
		    				&& responseObject.getData() != null
		    				&& SjjhConstant.RESPONSE_STATE_1.equals(responseObject.getData().getStatus())
		    				&& (SjjhConstant.RESPONSE_STATE_1.equals(responseObject.getData().getResult())
							|| SjjhConstant.RESPONSE_STATE_2.equals(responseObject.getData().getResult())
							|| SjjhConstant.RESPONSE_STATE_3.equals(responseObject.getData().getResult())
							|| SjjhConstant.RESPONSE_STATE_4.equals(responseObject.getData().getResult())
		    				|| SjjhConstant.RESPONSE_STATE_5.equals(responseObject.getData().getResult())
	    					|| SjjhConstant.RESPONSE_STATE_0.equals(responseObject.getData().getResult())));
	    		if(resultBool) {
	    	        ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
	    		}
	    		ret.setCode(Constant.SUCCESS);

	    		//根据客户来源返回对应码
	    		getOnlineStatusCode( ret, responseObject, returnType);

	    	}
	    } catch(SocketTimeoutException ste) {
	    	ErrorUtils.captureException(ste);
	    	ret.setCode(Constant.REQUEST_TIMEOUT);

	    } catch(UnrecognizedPropertyException upe) {
			log.info("yhLianTongOnlineStatusCheck-UnrecognizedPropertyException：{}", upe);
            ErrorUtils.captureException(upe);
            ret.setCode(Constant.SUCCESS);
            ret.setIsCharge(Constant.IS_NOT_CHARGE);
            /**参数错误*/
            if(Constant.CUSTOMER_RETURN_JK.equals(returnType)){
            	ret.setResultCode(Constant.JK_RETURN_CODE_9909);
            }else{
            	ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
        	ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            return ret;
		} catch(Exception ioe) {
	    	ErrorUtils.captureException(ioe);
	    	ret.setCode(Constant.FAIL);

	    }

    	request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
    	return ret;
    }

    /**
     * 在网状态和在网时长参数校验
     * @param returnType
     * @param mobile
     * @return
     */
    private ChannelTypeHandleResponseObject returnMobieCheckPara(String mobile,String returnType) {
    	ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
    	if(StringUtils.isBlank(mobile) || !PatternTools.checkResult(Constant.PATTERN_MOBILE_REGEX, mobile)) {
        	ret.setCode(Constant.SUCCESS);

        	if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
        		ret.setResultCode(Constant.MOBILE_FORMAT_ERROR_CODE);
        		ret.setResultDesc(Constant.MOBILE_FORMAT_ERROR);
        		ret.setResultBody(Constant.MOBILE_FORMAT_ERROR);
        	} else {
        		ret.setResultCode(Constant.JK_MOBILE_FORMAT_ERROR_CODE);
        		ret.setResultDesc(Constant.JK_MOBILE_FORMAT_ERROR);
        		ret.setResultBody(Constant.JK_MOBILE_FORMAT_ERROR);
        	}

        }

    	return ret;
    }

    /**
     * 返回联通在网时长
     * @param ret
     * @param responseObject
     * @param returnType
     * @return
     */
	private ChannelTypeHandleResponseObject getOnlineTimeCode(ChannelTypeHandleResponseObject ret,
			LianTongOnlineCheckResponseObject responseObject,String returnType) {
		boolean bool = SjjhConstant.RESPONSE_CODE_0.equals(responseObject.getCode())
				&& responseObject.getData() != null
				&& SjjhConstant.RESPONSE_STATE_1.equals(responseObject.getData().getStatus());
		if(bool && SjjhConstant.RESPONSE_STATE_1.equals(responseObject.getData().getResult())) {
			//1 个月及以下（用户状态正常时，含义为当月入网）
			if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.RETURN_CODE_46);
			} else {
				ret.setResultCode(Constant.JK_RETURN_CODE_1114);
			}
    		ret.setResultBody(SjjhConstant.RETURN_CODE_46_TEXT);
    		ret.setResultDesc(SjjhConstant.RETURN_CODE_46_TEXT);
		} else if(bool && SjjhConstant.RESPONSE_STATE_2.equals(responseObject.getData().getResult())) {
			//2 个月（用户状态正常时，含义为上个月入网）
			if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.RETURN_CODE_47);
			} else {
				ret.setResultCode(Constant.JK_RETURN_CODE_1115);
			}
			ret.setResultBody(SjjhConstant.RETURN_CODE_47_TEXT);
			ret.setResultDesc(SjjhConstant.RETURN_CODE_47_TEXT);
		} else if(bool && SjjhConstant.RESPONSE_STATE_3.equals(responseObject.getData().getResult())) {
			//3-6 个月
			if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.RETURN_CODE_48);
			} else {
				ret.setResultCode(Constant.JK_RETURN_CODE_1116);
			}
			ret.setResultBody(SjjhConstant.RETURN_CODE_48_TEXT);
			ret.setResultDesc(SjjhConstant.RETURN_CODE_48_TEXT);
		} else if(bool && SjjhConstant.RESPONSE_STATE_4.equals(responseObject.getData().getResult())) {
			//7-12 个月
			if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.RETURN_CODE_49);
			} else {
				ret.setResultCode(Constant.JK_RETURN_CODE_1117);
			}
			ret.setResultBody(SjjhConstant.RETURN_CODE_49_TEXT);
			ret.setResultDesc(SjjhConstant.RETURN_CODE_49_TEXT);
		} else if(bool && SjjhConstant.RESPONSE_STATE_5.equals(responseObject.getData().getResult())) {
			//13-24 个月
			if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.RETURN_CODE_50);
			} else {
				ret.setResultCode(Constant.JK_RETURN_CODE_1118);
			}
			ret.setResultBody(SjjhConstant.RETURN_CODE_50_TEXT);
			ret.setResultDesc(SjjhConstant.RETURN_CODE_50_TEXT);
		} else if(bool && SjjhConstant.RESPONSE_STATE_6.equals(responseObject.getData().getResult())) {
			//25-36 个月
			if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.RETURN_CODE_51);
			} else {
				ret.setResultCode(Constant.JK_RETURN_CODE_1119);
			}
			ret.setResultBody(SjjhConstant.RETURN_CODE_51_TEXT);
			ret.setResultDesc(SjjhConstant.RETURN_CODE_51_TEXT);
		} else if(bool && SjjhConstant.RESPONSE_STATE_7.equals(responseObject.getData().getResult())) {
			//37 个月及以上
			if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.RETURN_CODE_52);
			} else {
				ret.setResultCode(Constant.JK_RETURN_CODE_1120);
			}
			ret.setResultBody(SjjhConstant.RETURN_CODE_52_TEXT);
			ret.setResultDesc(SjjhConstant.RETURN_CODE_52_TEXT);
		} else if(SjjhConstant.RESPONSE_CODE_200.equals(responseObject.getCode())) {
			//库无
			if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.UN_FIND_NUM_CODE);
			} else {
				ret.setResultCode(Constant.JK_RETURN_CODE_NO_INFO);
			}
			ret.setResultBody(Constant.UN_FIND_NUM);
			ret.setResultDesc(Constant.UN_FIND_NUM);
		} else if(SjjhConstant.RESPONSE_CODE_205.equals(responseObject.getCode())) {
			//参数错误
			if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
			} else {
				ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
			}
			ret.setResultBody(Constant.INVALID_PARAMETER);
			ret.setResultDesc(Constant.INVALID_PARAMETER);
		} else if(SjjhConstant.RESPONSE_CODE_908.equals(responseObject.getCode())) {
			//号段不正确
			if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.PARAGRAPH_NUMBER_UNMATCH_CODE);
			} else {
				ret.setResultCode(Constant.JK_RETURN_CODE_NUMBER_UNMATCH);
			}
			ret.setResultBody(Constant.PARAGRAPH_NUMBER_UNMATCH);
			ret.setResultDesc(Constant.PARAGRAPH_NUMBER_UNMATCH);
		} else if(SjjhConstant.RESPONSE_CODE_207.equals(responseObject.getCode())) {
			//手机号码错误
			if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.MOBILE_FORMAT_ERROR_CODE);
				ret.setResultBody(Constant.MOBILE_FORMAT_ERROR);
				ret.setResultDesc(Constant.MOBILE_FORMAT_ERROR);
			} else {
				ret.setResultCode(Constant.JK_MOBILE_FORMAT_ERROR_CODE);
				ret.setResultBody(Constant.JK_MOBILE_FORMAT_ERROR);
				ret.setResultDesc(Constant.JK_MOBILE_FORMAT_ERROR);
			}
		} else {
			if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.OTHER_ERROR_CODE);
			} else {
				ret.setResultCode(Constant.JK_RETURN_CODE_OTHER_ERROR);
			}
			ret.setResultBody(SjjhConstant.PARAMETER_OTHER_ERROR);
			ret.setResultDesc(SjjhConstant.PARAMETER_OTHER_ERROR);
		}

		return ret;
	}

	/**
     * 返回联通在网状态
     * @param ret
     * @param responseObject
     * @param returnType
     * @return
     */
	private ChannelTypeHandleResponseObject getOnlineStatusCode(ChannelTypeHandleResponseObject ret,
			LianTongOnlineCheckResponseObject responseObject,String returnType) {
		boolean bool = SjjhConstant.RESPONSE_CODE_0.equals(responseObject.getCode())
				&& responseObject.getData() != null
				&& SjjhConstant.RESPONSE_STATE_1.equals(responseObject.getData().getStatus());
		if(bool && SjjhConstant.RESPONSE_STATE_0.equals(responseObject.getData().getResult())) {
			//非联通
			if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.RETURN_CODE_40);
			} else {
				ret.setResultCode(Constant.JK_RETURN_CODE_1121);
			}
    		ret.setResultBody(SjjhConstant.RETURN_CODE_40_TEXT);
    		ret.setResultDesc(SjjhConstant.RETURN_CODE_40_TEXT);
		} else if(bool && SjjhConstant.RESPONSE_STATE_1.equals(responseObject.getData().getResult())) {
			//未启用
			if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.RETURN_CODE_41);
			} else {
				ret.setResultCode(Constant.JK_RETURN_CODE_1122);
			}
			ret.setResultBody(SjjhConstant.RETURN_CODE_41_TEXT);
			ret.setResultDesc(SjjhConstant.RETURN_CODE_41_TEXT);
		} else if(bool && SjjhConstant.RESPONSE_STATE_2.equals(responseObject.getData().getResult())) {
			//正常
			if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.RETURN_CODE_42);
			} else {
				ret.setResultCode(Constant.JK_RETURN_CODE_1123);
			}
			ret.setResultBody(SjjhConstant.RETURN_CODE_42_TEXT);
			ret.setResultDesc(SjjhConstant.RETURN_CODE_42_TEXT);
		} else if(bool && SjjhConstant.RESPONSE_STATE_3.equals(responseObject.getData().getResult())) {
			//欠费停机
			if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.RETURN_CODE_43);
			} else {
				ret.setResultCode(Constant.JK_RETURN_CODE_1124);
			}
			ret.setResultBody(SjjhConstant.RETURN_CODE_43_TEXT);
			ret.setResultDesc(SjjhConstant.RETURN_CODE_43_TEXT);
		} else if(bool && SjjhConstant.RESPONSE_STATE_4.equals(responseObject.getData().getResult())) {
			//其它停机
			if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.RETURN_CODE_44);
			} else {
				ret.setResultCode(Constant.JK_RETURN_CODE_1125);
			}
			ret.setResultBody(SjjhConstant.RETURN_CODE_44_TEXT);
			ret.setResultDesc(SjjhConstant.RETURN_CODE_44_TEXT);
		} else if(bool && SjjhConstant.RESPONSE_STATE_5.equals(responseObject.getData().getResult())) {
			//已销号
			if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.RETURN_CODE_45);
			} else {
				ret.setResultCode(Constant.JK_RETURN_CODE_1126);
			}
			ret.setResultBody(SjjhConstant.RETURN_CODE_45_TEXT);
			ret.setResultDesc(SjjhConstant.RETURN_CODE_45_TEXT);
		} else if(SjjhConstant.RESPONSE_CODE_200.equals(responseObject.getCode())) {
			//库无
			if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.UN_FIND_NUM_CODE);
			} else {
				ret.setResultCode(Constant.JK_RETURN_CODE_NO_INFO);
			}
			ret.setResultBody(Constant.UN_FIND_NUM);
			ret.setResultDesc(Constant.UN_FIND_NUM);
		} else if(SjjhConstant.RESPONSE_CODE_205.equals(responseObject.getCode())) {
			//参数错误
			if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
			} else {
				ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
			}
			ret.setResultBody(Constant.INVALID_PARAMETER);
			ret.setResultDesc(Constant.INVALID_PARAMETER);
		} else if(SjjhConstant.RESPONSE_CODE_908.equals(responseObject.getCode())) {
			//号段不正确
			if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.PARAGRAPH_NUMBER_UNMATCH_CODE);
			} else {
				ret.setResultCode(Constant.JK_RETURN_CODE_NUMBER_UNMATCH);
			}
			ret.setResultBody(Constant.PARAGRAPH_NUMBER_UNMATCH);
			ret.setResultDesc(Constant.PARAGRAPH_NUMBER_UNMATCH);
		} else if(SjjhConstant.RESPONSE_CODE_207.equals(responseObject.getCode())) {
			//手机号码错误
			if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.MOBILE_FORMAT_ERROR_CODE);
				ret.setResultBody(Constant.MOBILE_FORMAT_ERROR);
				ret.setResultDesc(Constant.MOBILE_FORMAT_ERROR);
			} else {
				ret.setResultCode(Constant.JK_MOBILE_FORMAT_ERROR_CODE);
				ret.setResultBody(Constant.JK_MOBILE_FORMAT_ERROR);
				ret.setResultDesc(Constant.JK_MOBILE_FORMAT_ERROR);
			}
		} else {
			if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.OTHER_ERROR_CODE);
			} else {
				ret.setResultCode(Constant.JK_RETURN_CODE_OTHER_ERROR);
			}
			ret.setResultBody(SjjhConstant.PARAMETER_OTHER_ERROR);
			ret.setResultDesc(SjjhConstant.PARAMETER_OTHER_ERROR);
		}

		return ret;
	}

	@Override
    public ChannelTypeHandleResponseObject checkCMCCMobileOnlineStatus(HttpServletRequest request, String customBody, int outTime) {
		ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
        ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
        String upstreamCode = "" + Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
        String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
        if (StringUtils.isBlank(returnType)) {
            returnType = Constant.CUSTOMER_RETURN_ZW;
        }

        try {
            if (outTime <= 0) {
                outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
            }

            log.info("checkCMCCMobileOnlineStatus---customBody={},outTime={}", customBody, outTime);
            ObjectMapper objectMapper = new ObjectMapper();
            CheckCMCCOnlineJsonResolveObject jsonResolveObject = objectMapper.readValue(customBody,
                    CheckCMCCOnlineJsonResolveObject.class);


            log.info("checkCMCCMobileOnlineStatus---requestObject={}", jsonResolveObject);

			//参数校验
			boolean validateParamResult = validateCMCCOnlineParams(ret, returnType, jsonResolveObject);
			if (!validateParamResult) {
				request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
				return ret;
			}

            String params = Utils.encrypt(yhKey, "phone=" + jsonResolveObject.getMobile());
            FormBody.Builder formBodyBuilder = new FormBody.Builder()
                    .add("apiKey", checkCMCCOnlineStatusApiKey)
                    .add("username", yhUserName)
                    .add("params", params);
            log.info("supplier10000003.checkCMCCMobileOnlineStatus调用接口时传的参数：apiKey=" + checkCMCCOnlineStatusApiKey + ";username=" + yhUserName + ";params=" + params);

            Request okRequest = new Request.Builder()
                    .post(formBodyBuilder.build())
                    .url(yhUrl)
                    .build();
            Response response = getResponse( okRequest, outTime);
            String responseContext = "";
            if (response.body() != null) {
                responseContext = response.body().string();
            }
            log.info("supplier10000003.checkCMCCMobileOnlineStatus接口responseContext={}", responseContext);

            CheckCMCCOnlineStatusResponseObject responseObject = objectMapper.readValue(responseContext,
                    CheckCMCCOnlineStatusResponseObject.class);
            log.info("supplier10000003.checkCMCCMobileOnlineStatus接口responseObject={}", responseObject);

            if (responseObject != null) {

                ret.setCode(Constant.SUCCESS);
                getCMCCOnlineStatusResponse(ret, returnType, responseObject);
                upstreamCode = responseObject.getCode();
                response.close();
            } else {
                ret.setCode(Constant.FAIL);
            }
        } catch (SocketTimeoutException ste) {
            ErrorUtils.captureException(ste);
            log.info("supplier10000003.checkCMCCMobileOnlineStatus接口SocketTimeoutException={}", ste);
            ret.setCode(Constant.REQUEST_TIMEOUT);
        } catch(UnrecognizedPropertyException upe) {
			log.info("supplier10000003.checkCMCCMobileOnlineStatus-UnrecognizedPropertyException：{}", upe);
            ErrorUtils.captureException(upe);
            ret.setCode(Constant.SUCCESS);
            ret.setIsCharge(Constant.IS_NOT_CHARGE);
            /**参数错误*/
            if(Constant.CUSTOMER_RETURN_JK.equals(returnType)){
            	ret.setResultCode(Constant.JK_RETURN_CODE_9909);
            }else{
            	ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
            ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            return ret;
		} catch (Exception ioe) {
            ErrorUtils.captureException(ioe);
            log.info("supplier10000003.checkCMCCMobileOnlineStatus接口Exception={}", ioe);
            ret.setCode(Constant.FAIL);
        }

        //上游返回码
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        return ret;
    }

    private void getCMCCOnlineStatusResponse(ChannelTypeHandleResponseObject ret,
                                             String returnType,
                                             CheckCMCCOnlineStatusResponseObject responseObject) {
        boolean isCharge = responseObject != null
                && responseObject.getData() != null
                && "0".equals(responseObject.getCode())
                && "0".equals(responseObject.getData().getResultCode())
                && ArrayUtils.contains(SjjhConstant.CMCC_ONLINE_STATUS_SUCCESS_CODE, responseObject.getData().getState());
        if (isCharge) {
            ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
        }

        CheckCMCCOnlineStatusResponseObject.CheckCMCCOnlineStatusResponseData data = responseObject.getData();
        if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
            if (data != null && responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_0)
                    && data.getResultCode().equals(SjjhConstant.RESPONSE_RESULT_CODE_0) && data.getState().equals(SjjhConstant.RESPONSE_STATE_0)) {
                // 查询的手机号码在网
                ret.setResultCode(Constant.JK_RETURN_CODE_1127);
                ret.setResultBody(SjjhConstant.RETURN_CODE_25_TEXT);
                ret.setResultDesc(SjjhConstant.RETURN_CODE_25_TEXT);
            } else if (data != null && responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_0)
                    && data.getResultCode().equals(SjjhConstant.RESPONSE_RESULT_CODE_0) && data.getState().equals(SjjhConstant.RESPONSE_STATE_1)) {
                // 查询的手机号码停机
                ret.setResultCode(Constant.JK_RETURN_CODE_1128);
                ret.setResultBody(SjjhConstant.RETURN_CODE_26_TEXT);
                ret.setResultDesc(SjjhConstant.RETURN_CODE_26_TEXT);
            } else if (data != null && responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_0)
                    && data.getResultCode().equals(SjjhConstant.RESPONSE_RESULT_CODE_0) && data.getState().equals(SjjhConstant.RESPONSE_STATE_2)) {
                // 查询的在网但不可用
                ret.setResultCode(Constant.JK_RETURN_CODE_1129);
                ret.setResultBody(SjjhConstant.RETURN_CODE_27_TEXT);
                ret.setResultDesc(SjjhConstant.RETURN_CODE_27_TEXT);
            } else if (data != null && responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_0)
                    && data.getResultCode().equals(SjjhConstant.RESPONSE_RESULT_CODE_0) && data.getState().equals(SjjhConstant.RESPONSE_STATE_3)) {
                // 查询的手机销号/未启用
                ret.setResultCode(Constant.JK_RETURN_CODE_1130);
                ret.setResultBody(SjjhConstant.RETURN_CODE_28_TEXT);
                ret.setResultDesc(SjjhConstant.RETURN_CODE_28_TEXT);
            } else if (data != null && responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_0)
                    && data.getResultCode().equals(SjjhConstant.RESPONSE_RESULT_CODE_0) && data.getState().equals(SjjhConstant.RESPONSE_STATE_5)) {
                // 查询的手机号码预销号或空号
                ret.setResultCode(Constant.JK_RETURN_CODE_1131);
                ret.setResultBody(SjjhConstant.RETURN_CODE_29_TEXT);
                ret.setResultDesc(SjjhConstant.RETURN_CODE_29_TEXT);
            } else if (data != null && responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_0)
                    && data.getResultCode().equals(SjjhConstant.RESPONSE_RESULT_CODE_0) && data.getState().equals(SjjhConstant.RESPONSE_STATE_6)) {
                // 异常（号码状态异常）
                ret.setResultCode(Constant.JK_RETURN_CODE_1132);
                ret.setResultBody(SjjhConstant.RETURN_CODE_30_TEXT);
                ret.setResultDesc(SjjhConstant.RETURN_CODE_30_TEXT);
            } else if (responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_200)) {
                // 库无
                ret.setResultCode(Constant.JK_RETURN_CODE_NO_INFO);
                ret.setResultBody(Constant.UN_FIND_NUM);
                ret.setResultDesc(Constant.UN_FIND_NUM);
            } else if (responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_205)) {
                // 参数错误
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
                ret.setResultBody(Constant.INVALID_PARAMETER);
                ret.setResultDesc(Constant.INVALID_PARAMETER);
            } else if (responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_207)) {
                // 手机号码错误
                ret.setResultCode(Constant.JK_MOBILE_FORMAT_ERROR_CODE);
                ret.setResultBody(Constant.JK_MOBILE_FORMAT_ERROR);
                ret.setResultDesc(Constant.JK_MOBILE_FORMAT_ERROR);
            } else if (responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_908)) {
                // 号段不正确
                ret.setResultCode(Constant.JK_RETURN_CODE_NUMBER_UNMATCH);
                ret.setResultBody(Constant.PARAGRAPH_NUMBER_UNMATCH);
                ret.setResultDesc(Constant.PARAGRAPH_NUMBER_UNMATCH);
            } else {
                //其他错误
                ret.setResultCode(Constant.JK_RETURN_CODE_OTHER_ERROR);
                ret.setResultBody(Constant.OTHER_ERROR);
                ret.setResultDesc(Constant.OTHER_ERROR);
            }
        } else {
            if (data != null && responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_0) && data.getResultCode().equals(SjjhConstant.RESPONSE_RESULT_CODE_0) && data.getState().equals(SjjhConstant.RESPONSE_STATE_0)) {
                // 查询的手机号码在网
                ret.setResultCode(Constant.RETURN_CODE_25);
                ret.setResultBody(SjjhConstant.RETURN_CODE_25_TEXT);
                ret.setResultDesc(SjjhConstant.RETURN_CODE_25_TEXT);
            } else if (data != null && responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_0) && data.getResultCode().equals(SjjhConstant.RESPONSE_RESULT_CODE_0) && data.getState().equals(SjjhConstant.RESPONSE_STATE_1)) {
                // 查询的手机号码停机
                ret.setResultCode(Constant.RETURN_CODE_26);
                ret.setResultBody(SjjhConstant.RETURN_CODE_26_TEXT);
                ret.setResultDesc(SjjhConstant.RETURN_CODE_26_TEXT);
            } else if (data != null && responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_0) && data.getResultCode().equals(SjjhConstant.RESPONSE_RESULT_CODE_0) && data.getState().equals(SjjhConstant.RESPONSE_STATE_2)) {
                // 查询的在网但不可用
                ret.setResultCode(Constant.RETURN_CODE_27);
                ret.setResultBody(SjjhConstant.RETURN_CODE_27_TEXT);
                ret.setResultDesc(SjjhConstant.RETURN_CODE_27_TEXT);
            } else if (data != null && responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_0) && data.getResultCode().equals(SjjhConstant.RESPONSE_RESULT_CODE_0) && data.getState().equals(SjjhConstant.RESPONSE_STATE_3)) {
                // 查询的手机销号/未启用
                ret.setResultCode(Constant.RETURN_CODE_28);
                ret.setResultBody(SjjhConstant.RETURN_CODE_28_TEXT);
                ret.setResultDesc(SjjhConstant.RETURN_CODE_28_TEXT);
            } else if (data != null && responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_0) && data.getResultCode().equals(SjjhConstant.RESPONSE_RESULT_CODE_0) && data.getState().equals(SjjhConstant.RESPONSE_STATE_5)) {
                // 查询的手机号码预销号或空号
                ret.setResultCode(Constant.RETURN_CODE_29);
                ret.setResultBody(SjjhConstant.RETURN_CODE_29_TEXT);
                ret.setResultDesc(SjjhConstant.RETURN_CODE_29_TEXT);
            } else if (data != null && responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_0) && data.getResultCode().equals(SjjhConstant.RESPONSE_RESULT_CODE_0) && data.getState().equals(SjjhConstant.RESPONSE_STATE_6)) {
                // 异常（号码状态异常）
                ret.setResultCode(Constant.RETURN_CODE_30);
                ret.setResultBody(SjjhConstant.RETURN_CODE_30_TEXT);
                ret.setResultDesc(SjjhConstant.RETURN_CODE_30_TEXT);
            } else if (responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_200)) {
                // 库无
                ret.setResultCode(Constant.UN_FIND_NUM_CODE);
                ret.setResultBody(Constant.UN_FIND_NUM);
                ret.setResultDesc(Constant.UN_FIND_NUM);
            } else if (responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_205)) {
                // 参数错误
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
                ret.setResultBody(Constant.INVALID_PARAMETER);
                ret.setResultDesc(Constant.INVALID_PARAMETER);
            } else if (responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_207)) {
                // 手机号码错误
                ret.setResultCode(Constant.MOBILE_FORMAT_ERROR_CODE);
                ret.setResultBody(Constant.MOBILE_FORMAT_ERROR);
                ret.setResultDesc(Constant.MOBILE_FORMAT_ERROR);
            } else if (responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_908)) {
                // 号段不正确
                ret.setResultCode(Constant.PARAGRAPH_NUMBER_UNMATCH_CODE);
                ret.setResultBody(Constant.PARAGRAPH_NUMBER_UNMATCH);
                ret.setResultDesc(Constant.PARAGRAPH_NUMBER_UNMATCH);
            } else {
                //其他错误
                ret.setResultCode(Constant.OTHER_ERROR_CODE);
                ret.setResultBody(Constant.OTHER_ERROR);
                ret.setResultDesc(Constant.OTHER_ERROR);
            }
        }
    }

    @Override
    public ChannelTypeHandleResponseObject checkCMCCMobileOnlineTime(HttpServletRequest request, String customBody, int outTime) {
    	ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
        ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
        String upstreamCode = "" + Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
        String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
        if (StringUtils.isBlank(returnType)) {
            returnType = Constant.CUSTOMER_RETURN_ZW;
        }
        try {
            if (outTime <= 0) {
                outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
            }

            log.info("checkCMCCMobileOnlineTime---customBody={},outTime={}", customBody, outTime);
            ObjectMapper objectMapper = new ObjectMapper();
            CheckCMCCOnlineJsonResolveObject jsonResolveObject = objectMapper.readValue(customBody,
                    CheckCMCCOnlineJsonResolveObject.class);


            log.info("checkCMCCMobileOnlineTime---requestObject={}", jsonResolveObject);

			//参数校验
			boolean validateParamResult = validateCMCCOnlineParams(ret, returnType, jsonResolveObject);
			if (!validateParamResult) {
				request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
				return ret;
			}

            String params = Utils.encrypt(yhKey, "phone=" + jsonResolveObject.getMobile());
            FormBody.Builder formBodyBuilder = new FormBody.Builder()
                    .add("apiKey", checkCMCCOnlineTimeApiKey)
                    .add("username", yhUserName)
                    .add("params", params);
            log.info("supplier10000003.checkCMCCMobileOnlineTime调用接口时传的参数：apiKey=" + checkCMCCOnlineTimeApiKey + ";username=" + yhUserName + ";params=" + params);

            Request okRequest = new Request.Builder()
                    .post(formBodyBuilder.build())
                    .url(yhUrl)
                    .build();
            Response response = getResponse( okRequest, outTime);
            String responseContext = "";
            if (response.body() != null) {
                responseContext = response.body().string();
            }
            log.info("supplier10000003.checkCMCCMobileOnlineTime接口responseContext={}", responseContext);

            CheckCMCCOnlineTimeResponseObject responseObject = objectMapper.readValue(responseContext,
                    CheckCMCCOnlineTimeResponseObject.class);
            log.info("supplier10000003.checkCMCCMobileOnlineTime接口responseObject={}", responseObject);

            if (responseObject != null) {

                ret.setCode(Constant.SUCCESS);
                getCMCCOnlineTimeResponse(ret, returnType, responseObject);
                upstreamCode = responseObject.getCode();
                response.close();
            } else {
                ret.setCode(Constant.FAIL);
            }
        } catch (SocketTimeoutException ste) {
            ErrorUtils.captureException(ste);
            log.info("supplier10000003.checkCMCCMobileOnlineTime接口SocketTimeoutException={}", ste);
            ret.setCode(Constant.REQUEST_TIMEOUT);
        } catch(UnrecognizedPropertyException upe) {
			log.info("supplier10000003.checkCMCCMobileOnlineTime-UnrecognizedPropertyException：{}", upe);
            ErrorUtils.captureException(upe);
            ret.setCode(Constant.SUCCESS);
            ret.setIsCharge(Constant.IS_NOT_CHARGE);
            /**参数错误*/
            if(Constant.CUSTOMER_RETURN_JK.equals(returnType)){
            	ret.setResultCode(Constant.JK_RETURN_CODE_9909);
            }else{
            	ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
        	ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            return ret;
		} catch (Exception ioe) {
            ErrorUtils.captureException(ioe);
            log.info("supplier10000003.checkCMCCMobileOnlineTime接口Exception={}", ioe);
            ret.setCode(Constant.FAIL);
        }

        //上游返回码
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        return ret;
    }

    private void getCMCCOnlineTimeResponse(ChannelTypeHandleResponseObject ret,
                                           String returnType,
                                           CheckCMCCOnlineTimeResponseObject responseObject) {
        boolean isCharge = responseObject != null
                && responseObject.getData() != null
                && "0".equals(responseObject.getCode())
                && "0".equals(responseObject.getData().getResultCode());
        if (isCharge) {
            ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
        }
        CheckCMCCOnlineTimeResponseObject.CheckCMCCOnlineTimeResponseData data = responseObject.getData();
        if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
            if (data != null && responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_0)
                    && data.getResultCode().equals(SjjhConstant.RESPONSE_RESULT_CODE_0) && data.getResultValue().equals(SjjhConstant.RESULT_VALUE_1)) {
                // 0-3个月
                ret.setResultCode(Constant.JK_RETURN_CODE_1133);
                ret.setResultBody(SjjhConstant.RETURN_CODE_31_TEXT);
                ret.setResultDesc(SjjhConstant.RETURN_CODE_31_TEXT);
            } else if (data != null && responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_0)
                    && data.getResultCode().equals(SjjhConstant.RESPONSE_RESULT_CODE_0) && data.getResultValue().equals(SjjhConstant.RESULT_VALUE_2)) {
                // 3-6个月
                ret.setResultCode(Constant.JK_RETURN_CODE_1134);
                ret.setResultBody(SjjhConstant.RETURN_CODE_32_TEXT);
                ret.setResultDesc(SjjhConstant.RETURN_CODE_32_TEXT);
            } else if (data != null && responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_0)
                    && data.getResultCode().equals(SjjhConstant.RESPONSE_RESULT_CODE_0) && data.getResultValue().equals(SjjhConstant.RESULT_VALUE_3)) {
                // 6-12个月
                ret.setResultCode(Constant.JK_RETURN_CODE_1135);
                ret.setResultBody(SjjhConstant.RETURN_CODE_33_TEXT);
                ret.setResultDesc(SjjhConstant.RETURN_CODE_33_TEXT);
            } else if (data != null && responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_0)
                    && data.getResultCode().equals(SjjhConstant.RESPONSE_RESULT_CODE_0) && data.getResultValue().equals(SjjhConstant.RESULT_VALUE_4)) {
                // 12-18个月
                ret.setResultCode(Constant.JK_RETURN_CODE_1136);
                ret.setResultBody(SjjhConstant.RETURN_CODE_34_TEXT);
                ret.setResultDesc(SjjhConstant.RETURN_CODE_34_TEXT);
            } else if (data != null && responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_0)
                    && data.getResultCode().equals(SjjhConstant.RESPONSE_RESULT_CODE_0) && data.getResultValue().equals(SjjhConstant.RESULT_VALUE_5)) {
                // 18-24个月
                ret.setResultCode(Constant.JK_RETURN_CODE_1137);
                ret.setResultBody(SjjhConstant.RETURN_CODE_35_TEXT);
                ret.setResultDesc(SjjhConstant.RETURN_CODE_35_TEXT);
            } else if (data != null && responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_0)
                    && data.getResultCode().equals(SjjhConstant.RESPONSE_RESULT_CODE_0) && data.getResultValue().equals(SjjhConstant.RESULT_VALUE_6)) {
                // >24个月
                ret.setResultCode(Constant.JK_RETURN_CODE_1138);
                ret.setResultBody(SjjhConstant.RETURN_CODE_36_TEXT);
                ret.setResultDesc(SjjhConstant.RETURN_CODE_36_TEXT);
            } else if (responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_200)) {
                // 库无
                ret.setResultCode(Constant.JK_RETURN_CODE_NO_INFO);
                ret.setResultBody(Constant.UN_FIND_NUM);
                ret.setResultDesc(Constant.UN_FIND_NUM);
            } else if (responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_205)) {
                // 参数错误
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
                ret.setResultBody(Constant.INVALID_PARAMETER);
                ret.setResultDesc(Constant.INVALID_PARAMETER);
            } else if (responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_207)
                    || (responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_0)
                    && (data.getResultCode().equals(SjjhConstant.RESPONSE_RESULT_CODE_101)
                    || data.getResultCode().equals(SjjhConstant.RESPONSE_RESULT_CODE_102)))) {
                // 手机号码错误
                ret.setResultCode(Constant.JK_MOBILE_FORMAT_ERROR_CODE);
                ret.setResultBody(Constant.JK_MOBILE_FORMAT_ERROR);
                ret.setResultDesc(Constant.JK_MOBILE_FORMAT_ERROR);
            } else if (responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_908)
                    || (responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_0)
                    && data.getResultCode().equals(SjjhConstant.RESPONSE_RESULT_CODE_2))) {
                // 号段不正确
                ret.setResultCode(Constant.JK_RETURN_CODE_NUMBER_UNMATCH);
                ret.setResultBody(Constant.PARAGRAPH_NUMBER_UNMATCH);
                ret.setResultDesc(Constant.PARAGRAPH_NUMBER_UNMATCH);
            } else {
                //其他错误
                ret.setResultCode(Constant.JK_RETURN_CODE_OTHER_ERROR);
                ret.setResultBody(Constant.OTHER_ERROR);
                ret.setResultDesc(Constant.OTHER_ERROR);
            }
        } else {
            if (data != null && responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_0)
                    && data.getResultCode().equals(SjjhConstant.RESPONSE_RESULT_CODE_0) && data.getResultValue().equals(SjjhConstant.RESULT_VALUE_1)) {
                // 0-3个月
                ret.setResultCode(Constant.RETURN_CODE_31);
                ret.setResultBody(SjjhConstant.RETURN_CODE_31_TEXT);
                ret.setResultDesc(SjjhConstant.RETURN_CODE_31_TEXT);
            } else if (data != null && responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_0)
                    && data.getResultCode().equals(SjjhConstant.RESPONSE_RESULT_CODE_0) && data.getResultValue().equals(SjjhConstant.RESULT_VALUE_2)) {
                // 3-6个月
                ret.setResultCode(Constant.RETURN_CODE_32);
                ret.setResultBody(SjjhConstant.RETURN_CODE_32_TEXT);
                ret.setResultDesc(SjjhConstant.RETURN_CODE_32_TEXT);
            } else if (data != null && responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_0)
                    && data.getResultCode().equals(SjjhConstant.RESPONSE_RESULT_CODE_0) && data.getResultValue().equals(SjjhConstant.RESULT_VALUE_3)) {
                // 6-12个月
                ret.setResultCode(Constant.RETURN_CODE_33);
                ret.setResultBody(SjjhConstant.RETURN_CODE_33_TEXT);
                ret.setResultDesc(SjjhConstant.RETURN_CODE_33_TEXT);
            } else if (data != null && responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_0)
                    && data.getResultCode().equals(SjjhConstant.RESPONSE_RESULT_CODE_0) && data.getResultValue().equals(SjjhConstant.RESULT_VALUE_4)) {
                // 12-18个月
                ret.setResultCode(Constant.RETURN_CODE_34);
                ret.setResultBody(SjjhConstant.RETURN_CODE_34_TEXT);
                ret.setResultDesc(SjjhConstant.RETURN_CODE_34_TEXT);
            } else if (data != null && responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_0)
                    && data.getResultCode().equals(SjjhConstant.RESPONSE_RESULT_CODE_0) && data.getResultValue().equals(SjjhConstant.RESULT_VALUE_5)) {
                // 18-24个月
                ret.setResultCode(Constant.RETURN_CODE_35);
                ret.setResultBody(SjjhConstant.RETURN_CODE_35_TEXT);
                ret.setResultDesc(SjjhConstant.RETURN_CODE_35_TEXT);
            } else if (data != null && responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_0)
                    && data.getResultCode().equals(SjjhConstant.RESPONSE_RESULT_CODE_0) && data.getResultValue().equals(SjjhConstant.RESULT_VALUE_6)) {
                // >24个月
                ret.setResultCode(Constant.RETURN_CODE_36);
                ret.setResultBody(SjjhConstant.RETURN_CODE_36_TEXT);
                ret.setResultDesc(SjjhConstant.RETURN_CODE_36_TEXT);
            } else if (responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_200)) {
                // 库无
                ret.setResultCode(Constant.UN_FIND_NUM_CODE);
                ret.setResultBody(Constant.UN_FIND_NUM);
                ret.setResultDesc(Constant.UN_FIND_NUM);
            } else if (responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_205)) {
                // 参数错误
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
                ret.setResultBody(Constant.INVALID_PARAMETER);
                ret.setResultDesc(Constant.INVALID_PARAMETER);
            } else if (responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_207)
                    || (responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_0)
                    && (data.getResultCode().equals(SjjhConstant.RESPONSE_RESULT_CODE_101)
                    || data.getResultCode().equals(SjjhConstant.RESPONSE_RESULT_CODE_102)))) {
                // 手机号码错误
                ret.setResultCode(Constant.MOBILE_FORMAT_ERROR_CODE);
                ret.setResultBody(Constant.MOBILE_FORMAT_ERROR);
                ret.setResultDesc(Constant.MOBILE_FORMAT_ERROR);
            } else if (responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_908)
                    || (responseObject.getCode().equals(SjjhConstant.RESPONSE_CODE_0)
                    && data.getResultCode().equals(SjjhConstant.RESPONSE_RESULT_CODE_2))) {
                // 号段不正确
                ret.setResultCode(Constant.PARAGRAPH_NUMBER_UNMATCH_CODE);
                ret.setResultBody(Constant.PARAGRAPH_NUMBER_UNMATCH);
                ret.setResultDesc(Constant.PARAGRAPH_NUMBER_UNMATCH);
            } else {
                //其他错误
                ret.setResultCode(Constant.OTHER_ERROR_CODE);
                ret.setResultBody(Constant.OTHER_ERROR);
                ret.setResultDesc(Constant.OTHER_ERROR);
            }
        }
    }

	private boolean validateCMCCOnlineParams(ChannelTypeHandleResponseObject ret, String returnType,
											 CheckCMCCOnlineJsonResolveObject jsonResolveObject) {
		ValidatorFactory vf = Validation.buildDefaultValidatorFactory();
		Validator validator = vf.getValidator();
		Set<ConstraintViolation<CheckCMCCOnlineJsonResolveObject>> set = validator.validate(jsonResolveObject);
		String message = "";
		for (ConstraintViolation<CheckCMCCOnlineJsonResolveObject> con : set) {
			message = con.getMessage();
		}
		// 验证参数名是否正确
		if (StringUtils.isNotBlank(message)) {
			if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
				ret.setResultDesc(Constant.INVALID_PARAMETER);
				ret.setResultBody(Constant.INVALID_PARAMETER);
			} else {
				ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
				ret.setResultDesc(Constant.INVALID_PARAMETER);
				ret.setResultBody(Constant.INVALID_PARAMETER);
			}
			return false;
		}

		boolean paraBool = StringUtils.isBlank(jsonResolveObject.getMobile()) ||
				!PatternTools.checkResult(Constant.PATTERN_MOBILE_REGEX, jsonResolveObject.getMobile());
		if (paraBool) {
			ret.setCode(Constant.SUCCESS);
			if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.MOBILE_FORMAT_ERROR_CODE);
				ret.setResultDesc(Constant.MOBILE_FORMAT_ERROR);
				ret.setResultBody(Constant.MOBILE_FORMAT_ERROR);
			} else {
				ret.setResultCode(Constant.JK_MOBILE_FORMAT_ERROR_CODE);
				ret.setResultDesc(Constant.JK_MOBILE_FORMAT_ERROR);
				ret.setResultBody(Constant.JK_MOBILE_FORMAT_ERROR);
			}
			return false;
		}
		return true;
	}
	
	@Override
    public ChannelTypeHandleResponseObject lianTongCostScore(HttpServletRequest request, String customBody, int outTime) {
    	ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
        ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
        String upstreamCode = "" + Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
        if (StringUtils.isBlank(returnType)) {
            returnType = Constant.CUSTOMER_RETURN_ZW;
        }
        try {
            if (outTime <= 0) {
                outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
            }

            log.info("supplier10000003.lianTongCostScore---customBody={},outTime={}", customBody, outTime);
            ObjectMapper objectMapper = new ObjectMapper();
            LianTongOnlineJsonObject jsonResolveObject = objectMapper.readValue(customBody,
            		LianTongOnlineJsonObject.class);


            log.info("supplier10000003.lianTongCostScore---requestObject={}", jsonResolveObject);

			//参数校验
			ret = returnMobieCheckPara(jsonResolveObject.getMobile(), returnType);
			if(StringUtils.isNotBlank(ret.getResultDesc())) {
	        	return ret;
	        }

            String params = Utils.encrypt(yhKey, "phone=" + jsonResolveObject.getMobile());
            FormBody.Builder formBodyBuilder = new FormBody.Builder()
                    .add("apiKey", yhApiKeyY001w1)
                    .add("username", yhUserName)
                    .add("params", params);
            log.info("supplier10000003.lianTongCostScore调用接口时传的参数：apiKey=" + yhApiKeyY001w1 + ";username=" + yhUserName + ";params=" + params);

            Request okRequest = new Request.Builder()
                    .post(formBodyBuilder.build())
                    .url(yhUrl)
                    .build();
            Response response = getResponse( okRequest, outTime);
            String responseContext = "";
            if (response.body() != null) {
                responseContext = response.body().string();
            }
            log.info("supplier10000003.lianTongCostScore接口responseContext={}", responseContext);

            LianTongCostScoreResponseObject responseObject = objectMapper.readValue(responseContext,
            		LianTongCostScoreResponseObject.class);
            log.info("supplier10000003.lianTongCostScore接口responseObject={}", responseObject);

            if (responseObject != null) {
                ret.setCode(Constant.SUCCESS);
                getLianTongCostScoreResponseObject(ret, returnType, responseObject);
                upstreamCode = responseObject.getCode();
                response.close();
            } else {
                ret.setCode(Constant.FAIL);
            }
        } catch (SocketTimeoutException ste) {
            ErrorUtils.captureException(ste);
            log.info("supplier10000003.lianTongCostScore接口SocketTimeoutException={}", ste);
            ret.setCode(Constant.REQUEST_TIMEOUT);
        } catch(UnrecognizedPropertyException upe) {
			log.info("supplier10000003.lianTongCostScore-UnrecognizedPropertyException：{}", upe);
            ErrorUtils.captureException(upe);
            ret.setCode(Constant.SUCCESS);
            ret.setIsCharge(Constant.IS_NOT_CHARGE);
            /**参数错误*/
            if(Constant.CUSTOMER_RETURN_JK.equals(returnType)){
            	ret.setResultCode(Constant.JK_RETURN_CODE_9909);
            }else{
            	ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
        	ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            return ret;
		} catch (Exception ioe) {
            ErrorUtils.captureException(ioe);
            log.info("supplier10000003.lianTongCostScore接口Exception={}", ioe);
            ret.setCode(Constant.FAIL);
        }

        //上游返回码
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        return ret;
    }

	/**
	 * 联通手机话费平均评分接口:根据不同客户返回不同码
	 * @param ret
	 * @param returnType
	 * @param responseObject
	 * @return
	 */
    private ChannelTypeHandleResponseObject getLianTongCostScoreResponseObject(
    		ChannelTypeHandleResponseObject ret,String returnType,
    		LianTongCostScoreResponseObject responseObject) {
    	boolean  bool = SjjhConstant.RESPONSE_CODE_0.equals(responseObject.getCode()) && 
    			responseObject.getData() != null;
    	boolean isCharge = (bool
                && (SjjhConstant.USER_MONTH_COST_0.equals(responseObject.getData().getScore())
                || SjjhConstant.USER_MONTH_COST_40.equals(responseObject.getData().getScore())
                || SjjhConstant.USER_MONTH_COST_80.equals(responseObject.getData().getScore())
                || SjjhConstant.USER_MONTH_COST_160.equals(responseObject.getData().getScore())
                || SjjhConstant.USER_MONTH_COST_999.equals(responseObject.getData().getScore()))) 
                || SjjhConstant.RESPONSE_CODE_200.equals(responseObject.getCode());
        if (isCharge) {
            ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
        }
    	
    	if(bool && SjjhConstant.USER_MONTH_COST_0.equals(responseObject.getData().getScore())) {
			//用户月话费为 0
    		if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
    			ret.setResultCode(Constant.JK_RETURN_CODE_1156);
    		} else {
    			ret.setResultCode(Constant.RETURN_CODE_84);
    		}
			ret.setResultBody(SjjhConstant.USER_MONTH_COST_0_TEXT);
			ret.setResultDesc(SjjhConstant.USER_MONTH_COST_0_TEXT);
		} else if(bool && SjjhConstant.USER_MONTH_COST_40.equals(responseObject.getData().getScore())) {
			//用户月话费为(0,40]
			if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
				ret.setResultCode(Constant.JK_RETURN_CODE_1157);
			} else {
				ret.setResultCode(Constant.RETURN_CODE_85);
			}
			ret.setResultBody(SjjhConstant.USER_MONTH_COST_40_TEXT);
			ret.setResultDesc(SjjhConstant.USER_MONTH_COST_40_TEXT);
		} else if(bool && SjjhConstant.USER_MONTH_COST_80.equals(responseObject.getData().getScore())) {
			//用户月话费为(40,80]
			if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
				ret.setResultCode(Constant.JK_RETURN_CODE_1158);
			} else {
				ret.setResultCode(Constant.RETURN_CODE_86);
			}
			ret.setResultBody(SjjhConstant.USER_MONTH_COST_80_TEXT);
			ret.setResultDesc(SjjhConstant.USER_MONTH_COST_80_TEXT);
		} else if(bool && SjjhConstant.USER_MONTH_COST_160.equals(responseObject.getData().getScore())) {
			//用户月话费为(80,160]
			if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
				ret.setResultCode(Constant.JK_RETURN_CODE_1159);
			} else {
				ret.setResultCode(Constant.RETURN_CODE_87);
			}
			ret.setResultBody(SjjhConstant.USER_MONTH_COST_160_TEXT);
			ret.setResultDesc(SjjhConstant.USER_MONTH_COST_160_TEXT);
		}  else if(bool && SjjhConstant.USER_MONTH_COST_999.equals(responseObject.getData().getScore())) {
			//用户月话费为>160
			if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
				ret.setResultCode(Constant.JK_RETURN_CODE_1160);
			} else {
				ret.setResultCode(Constant.RETURN_CODE_88);
			}
			ret.setResultBody(SjjhConstant.USER_MONTH_COST_GREATER_160_TEXT);
			ret.setResultDesc(SjjhConstant.USER_MONTH_COST_GREATER_160_TEXT);
		} else if(SjjhConstant.RESPONSE_CODE_205.equals(responseObject.getCode())) {
			//参数错误
			if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
				ret.setResultCode(Constant.JK_RETURN_CODE_9909);
			} else {
				ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
			}
			ret.setResultBody(Constant.INVALID_PARAMETER);
			ret.setResultDesc(Constant.INVALID_PARAMETER);
		} else if(SjjhConstant.RESPONSE_CODE_207.equals(responseObject.getCode())) {
			//手机号格式错误
			if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.MOBILE_FORMAT_ERROR_CODE);
				ret.setResultBody(Constant.MOBILE_FORMAT_ERROR);
				ret.setResultDesc(Constant.MOBILE_FORMAT_ERROR);
			} else {
				ret.setResultCode(Constant.JK_MOBILE_FORMAT_ERROR_CODE);
				ret.setResultBody(Constant.JK_MOBILE_FORMAT_ERROR);
				ret.setResultDesc(Constant.JK_MOBILE_FORMAT_ERROR);
			}
		} else if(SjjhConstant.RESPONSE_CODE_908.equals(responseObject.getCode())) {
			//号段不正确
			if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
				ret.setResultCode(Constant.JK_RETURN_CODE_NUMBER_UNMATCH);
			} else {
				ret.setResultCode(Constant.PARAGRAPH_NUMBER_UNMATCH_CODE);
			}
			ret.setResultBody(Constant.PARAGRAPH_NUMBER_UNMATCH);
			ret.setResultDesc(Constant.PARAGRAPH_NUMBER_UNMATCH);
		} else if(SjjhConstant.RESPONSE_CODE_200.equals(responseObject.getCode())) {
			//库无
			if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
				ret.setResultCode(Constant.JK_RETURN_CODE_NO_INFO);
			} else {
				ret.setResultCode(Constant.UN_FIND_NUM_CODE);
			}
			ret.setResultBody(SjjhConstant.INTERFACE_NO_FIND_TEXT);
			ret.setResultDesc(SjjhConstant.INTERFACE_NO_FIND_TEXT);
		} else {
			//查询错误
			if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
				ret.setResultCode(Constant.JK_RETURN_CODE_OTHER_ERROR);
			} else {
				ret.setResultCode(Constant.OTHER_ERROR_CODE);
			}
			ret.setResultBody(Constant.OTHER_ERROR);
			ret.setResultDesc(Constant.OTHER_ERROR);
		}
    	
    	
    	return ret;
    }
    
    @Override
    public ChannelTypeHandleResponseObject dianXinMonthCost(HttpServletRequest request, String customBody, int outTime) {
    	ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
        ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
        String upstreamCode = "" + Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
        if (StringUtils.isBlank(returnType)) {
            returnType = Constant.CUSTOMER_RETURN_ZW;
        }
        try {
            if (outTime <= 0) {
                outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
            }

            log.info("supplier10000003.dianXinMonthCost---customBody={},outTime={}", customBody, outTime);
            ObjectMapper objectMapper = new ObjectMapper();
            CheckCMCCOnlineJsonResolveObject jsonResolveObject = objectMapper.readValue(customBody,
                    CheckCMCCOnlineJsonResolveObject.class);


            log.info("supplier10000003.dianXinMonthCost---requestObject={}", jsonResolveObject);

			//参数校验
            ret = returnMobieCheckPara(jsonResolveObject.getMobile(), returnType);
			if(StringUtils.isNotBlank(ret.getResultDesc())) {
	        	return ret;
	        }

            String params = Utils.encrypt(yhKey, "phone=" + jsonResolveObject.getMobile());
            FormBody.Builder formBodyBuilder = new FormBody.Builder()
                    .add("apiKey", yhApiKeyY001x1)
                    .add("username", yhUserName)
                    .add("params", params);
            log.info("supplier10000003.dianXinMonthCost调用接口时传的参数：apiKey=" + yhApiKeyY001x1 + ";username=" + yhUserName + ";params=" + params);

            Request okRequest = new Request.Builder()
                    .post(formBodyBuilder.build())
                    .url(yhUrl)
                    .build();
            Response response = getResponse( okRequest, outTime);
            String responseContext = "";
            if (response.body() != null) {
                responseContext = response.body().string();
            }
            log.info("supplier10000003.dianXinMonthCost接口responseContext={}", responseContext);

            DianXinMonthCostResponseObject responseObject = objectMapper.readValue(responseContext,
            		DianXinMonthCostResponseObject.class);
            log.info("supplier10000003.dianXinMonthCost接口responseObject={}", responseObject);

            if (responseObject != null) {

                ret.setCode(Constant.SUCCESS);
                getDianXinCostScoreResponseObject(objectMapper, ret, returnType, responseObject);
                upstreamCode = responseObject.getCode();
                response.close();
            } else {
                ret.setCode(Constant.FAIL);
            }
        } catch (SocketTimeoutException ste) {
            ErrorUtils.captureException(ste);
            log.info("supplier10000003.dianXinMonthCost接口SocketTimeoutException={}", ste);
            ret.setCode(Constant.REQUEST_TIMEOUT);
        } catch(UnrecognizedPropertyException upe) {
			log.info("supplier10000003.dianXinMonthCost-UnrecognizedPropertyException：{}", upe);
            ErrorUtils.captureException(upe);
            ret.setCode(Constant.SUCCESS);
            ret.setIsCharge(Constant.IS_NOT_CHARGE);
            /**参数错误*/
            if(Constant.CUSTOMER_RETURN_JK.equals(returnType)){
            	ret.setResultCode(Constant.JK_RETURN_CODE_9909);
            }else{
            	ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
        	ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            return ret;
		} catch (Exception ioe) {
            ErrorUtils.captureException(ioe);
            log.info("supplier10000003.dianXinMonthCost接口Exception={}", ioe);
            ret.setCode(Constant.FAIL);
        }

        //上游返回码
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        return ret;
    }
    
    /**
	 * 电信月消费金额接口:根据不同客户返回不同码
	 * @param ret
	 * @param returnType
	 * @param responseObject
	 * @return
	 */
    private ChannelTypeHandleResponseObject getDianXinCostScoreResponseObject(
    		ObjectMapper objectMapper,
    		ChannelTypeHandleResponseObject ret,String returnType,
    		DianXinMonthCostResponseObject responseObject) throws JsonProcessingException{
    	boolean isCharge = responseObject != null
                && SjjhConstant.RESPONSE_CODE_0.equals(responseObject.getCode());
        if (isCharge) {
            ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
        }
    	
    	if(responseObject != null && SjjhConstant.RESPONSE_CODE_0.equals(responseObject.getCode())) {
			//查询成功
    		if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
    			ret.setResultCode(Constant.JK_RETURN_CODE_MATCH);
    		} else {
    			ret.setResultCode(Constant.MATCH_CODE);
    		}
			ret.setResultBody(objectMapper.writeValueAsString(responseObject.getData()));
			ret.setResultDesc(SjjhConstant.QUERY_SUCCESS);
		} else if(responseObject != null && SjjhConstant.RESPONSE_CODE_200.equals(responseObject.getCode())) {
			//库无
			if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
				ret.setResultCode(Constant.JK_RETURN_CODE_NO_INFO);
			} else {
				ret.setResultCode(Constant.UN_FIND_NUM_CODE);
			}
			ret.setResultBody(SjjhConstant.INTERFACE_NO_FIND_TEXT);
			ret.setResultDesc(SjjhConstant.INTERFACE_NO_FIND_TEXT);
		} else if(responseObject != null && SjjhConstant.RESPONSE_CODE_205.equals(responseObject.getCode())) {
			//参数错误
			if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
				ret.setResultCode(Constant.JK_RETURN_CODE_9909);
			} else {
				ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
			}
			ret.setResultBody(Constant.INVALID_PARAMETER);
			ret.setResultDesc(Constant.INVALID_PARAMETER);
		} else if(responseObject != null && SjjhConstant.RESPONSE_CODE_207.equals(responseObject.getCode())) {
			//手机号格式错误
			if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.MOBILE_FORMAT_ERROR_CODE);
				ret.setResultBody(Constant.MOBILE_FORMAT_ERROR);
				ret.setResultDesc(Constant.MOBILE_FORMAT_ERROR);
			} else {
				ret.setResultCode(Constant.JK_MOBILE_FORMAT_ERROR_CODE);
				ret.setResultBody(Constant.JK_MOBILE_FORMAT_ERROR);
				ret.setResultDesc(Constant.JK_MOBILE_FORMAT_ERROR);
			}
		}  else if(responseObject != null && SjjhConstant.RESPONSE_CODE_908.equals(responseObject.getCode())) {
			//号段不正确
			if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
				ret.setResultCode(Constant.JK_RETURN_CODE_NUMBER_UNMATCH);
			} else {
				ret.setResultCode(Constant.PARAGRAPH_NUMBER_UNMATCH_CODE);
			}
			ret.setResultBody(Constant.PARAGRAPH_NUMBER_UNMATCH);
			ret.setResultDesc(Constant.PARAGRAPH_NUMBER_UNMATCH);
		}else {
			//其他错误
			if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
				ret.setResultCode(Constant.JK_RETURN_CODE_OTHER_ERROR);
			} else {
				ret.setResultCode(Constant.OTHER_ERROR_CODE);
			}
			ret.setResultBody(Constant.OTHER_ERROR);
			ret.setResultDesc(Constant.OTHER_ERROR);
		}
    	
    	
    	return ret;
    }
    
    @Override
    public ChannelTypeHandleResponseObject queryMobileConsumeSection(HttpServletRequest request, 
    		String customBody, int outTime) {
    	ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
        ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
        String upstreamCode = "" + Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
        if (StringUtils.isBlank(returnType)) {
            returnType = Constant.CUSTOMER_RETURN_ZW;
        }
        try {
            if (outTime <= 0) {
                outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
            }

            log.info("supplier10000003.queryMobileConsumeSection---customBody={},outTime={}", customBody, outTime);
            ObjectMapper objectMapper = new ObjectMapper();
            QueryMobileConsumeJsonResolveObject jsonResolveObject = objectMapper.readValue(customBody,
            		QueryMobileConsumeJsonResolveObject.class);


            log.info("supplier10000003.queryMobileConsumeSection---requestObject={}", jsonResolveObject);

			//参数校验
			ret = returnMobieCheckPara(jsonResolveObject.getMobile(), returnType);
			if(StringUtils.isNotBlank(ret.getResultDesc())) {
	        	return ret;
	        }
			if(StringUtils.isBlank(jsonResolveObject.getRangeCode()) || 
					!NumberUtils.isDigits(jsonResolveObject.getRangeCode()) || 
					NumberUtils.toInt(jsonResolveObject.getRangeCode()) < 1 || 
					NumberUtils.toInt(jsonResolveObject.getRangeCode()) > 12 ) {
				if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
					ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
				} else {
					ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
				}
				ret.setResultBody(SjjhConstant.MONTH_NUMBER_ERROR_TITLE);
				ret.setResultDesc(SjjhConstant.MONTH_NUMBER_ERROR_TITLE);
				return ret;
				
			}
			

            String params = Utils.encrypt(yhKey, "phone=" + jsonResolveObject.getMobile() + "&rangeCode=" + jsonResolveObject.getRangeCode());
            FormBody.Builder formBodyBuilder = new FormBody.Builder()
                    .add("apiKey", yhApiKeyY002y1)
                    .add("username", yhUserName)
                    .add("params", params);
            log.info("supplier10000003.queryMobileConsumeSection调用接口时传的参数：apiKey=" + yhApiKeyY002y1 + ";username=" + yhUserName + ";params=" + params);

            Request okRequest = new Request.Builder()
                    .post(formBodyBuilder.build())
                    .url(yhUrl)
                    .build();

            Response response = getResponse( okRequest, outTime);
            String responseContext = "";
            if (response.body() != null) {
                responseContext = response.body().string();
            }
            log.info("supplier10000003.queryMobileConsumeSection接口responseContext={}", responseContext);

            CheckCMCCOnlineTimeResponseObject responseObject = objectMapper.readValue(responseContext,
            		CheckCMCCOnlineTimeResponseObject.class);
            log.info("supplier10000003.queryMobileConsumeSection接口responseObject={}", responseObject);

            if (responseObject != null) {
                ret.setCode(Constant.SUCCESS);
                getQueryMobileConsumeResponseObject(objectMapper, ret, returnType, responseObject);
                upstreamCode = responseObject.getCode();
                response.close();
            } else {
                ret.setCode(Constant.FAIL);
            }
        } catch (SocketTimeoutException ste) {
            ErrorUtils.captureException(ste);
            log.info("supplier10000003.queryMobileConsumeSection接口SocketTimeoutException={}", ste);
            ret.setCode(Constant.REQUEST_TIMEOUT);
        } catch(UnrecognizedPropertyException upe) {
			log.info("supplier10000003.queryMobileConsumeSection-UnrecognizedPropertyException：{}", upe);
            ErrorUtils.captureException(upe);
            ret.setCode(Constant.SUCCESS);
            ret.setIsCharge(Constant.IS_NOT_CHARGE);
            /**参数错误*/
            if(Constant.CUSTOMER_RETURN_JK.equals(returnType)){
            	ret.setResultCode(Constant.JK_RETURN_CODE_9909);
            }else{
            	ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
        	ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            return ret;
		} catch (Exception ioe) {
            ErrorUtils.captureException(ioe);
            log.info("supplier10000003.queryMobileConsumeSection接口Exception={}", ioe);
            ret.setCode(Constant.FAIL);
        }

        //上游返回码
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        return ret;
    }
    
    /**
	 * 移动手机消费区间查询接口:根据不同客户返回不同码
	 * @param ret
	 * @param returnType
	 * @param responseObject
	 * @return
	 */
    private ChannelTypeHandleResponseObject getQueryMobileConsumeResponseObject(
    		ObjectMapper objectMapper,
    		ChannelTypeHandleResponseObject ret,String returnType,
    		CheckCMCCOnlineTimeResponseObject responseObject) throws JsonProcessingException{
    	boolean isCharge = responseObject != null
                && SjjhConstant.RESPONSE_CODE_0.equals(responseObject.getCode())
                && responseObject.getData() != null 
                && SjjhConstant.RESPONSE_CODE_0.equals(responseObject.getData().getResultCode());
        if (isCharge) {
            ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
        }
        
        //号段不正确的判断
        boolean bool1 = responseObject != null && 
				(SjjhConstant.RESPONSE_CODE_908.equals(responseObject.getCode()) 
						|| (SjjhConstant.RESPONSE_CODE_0.equals(responseObject.getCode()) 
								&& SjjhConstant.RESPONSE_RESULT_CODE_2.equals(responseObject.getData().getResultCode())));
        //手机号格式错误的判断
        boolean bool2= responseObject != null 
				&& (SjjhConstant.RESPONSE_CODE_207.equals(responseObject.getCode())
						|| (SjjhConstant.RESPONSE_CODE_0.equals(responseObject.getCode()) 
								&& SjjhConstant.RESPONSE_RESULT_CODE_101.equals(responseObject.getData().getResultCode()))
						|| (SjjhConstant.RESPONSE_CODE_0.equals(responseObject.getCode()) 
								&& SjjhConstant.RESPONSE_RESULT_CODE_102.equals(responseObject.getData().getResultCode())));
    	
    	if(isCharge) {
			//查询成功
    		if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
    			ret.setResultCode(Constant.JK_RETURN_CODE_MATCH);
    		} else {
    			ret.setResultCode(Constant.MATCH_CODE);
    		}
			ret.setResultBody(objectMapper.writeValueAsString(responseObject.getData()));
			ret.setResultDesc(SjjhConstant.QUERY_SUCCESS);
		} else if(responseObject != null && SjjhConstant.RESPONSE_CODE_200.equals(responseObject.getCode())) {
			//库无
			if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
				ret.setResultCode(Constant.JK_RETURN_CODE_NO_INFO);
			} else {
				ret.setResultCode(Constant.UN_FIND_NUM_CODE);
			}
			ret.setResultBody(SjjhConstant.INTERFACE_NO_FIND_TEXT);
			ret.setResultDesc(SjjhConstant.INTERFACE_NO_FIND_TEXT);
		} else if(responseObject != null && SjjhConstant.RESPONSE_CODE_205.equals(responseObject.getCode())) {
			//参数错误
			if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
				ret.setResultCode(Constant.JK_RETURN_CODE_9909);
			} else {
				ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
			}
			ret.setResultBody(Constant.INVALID_PARAMETER);
			ret.setResultDesc(Constant.INVALID_PARAMETER);
		} else if(bool2) {
			//手机号格式错误
			if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.MOBILE_FORMAT_ERROR_CODE);
				ret.setResultBody(Constant.MOBILE_FORMAT_ERROR);
				ret.setResultDesc(Constant.MOBILE_FORMAT_ERROR);
			} else {
				ret.setResultCode(Constant.JK_MOBILE_FORMAT_ERROR_CODE);
				ret.setResultBody(Constant.JK_MOBILE_FORMAT_ERROR);
				ret.setResultDesc(Constant.JK_MOBILE_FORMAT_ERROR);
			}
		}  else if(bool1) {
			//号段不正确
			if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
				ret.setResultCode(Constant.JK_RETURN_CODE_NUMBER_UNMATCH);
			} else {
				ret.setResultCode(Constant.PARAGRAPH_NUMBER_UNMATCH_CODE);
			}
			ret.setResultBody(Constant.PARAGRAPH_NUMBER_UNMATCH);
			ret.setResultDesc(Constant.PARAGRAPH_NUMBER_UNMATCH);
		}else {
			//其他错误
			if(Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
				ret.setResultCode(Constant.JK_RETURN_CODE_OTHER_ERROR);
			} else {
				ret.setResultCode(Constant.OTHER_ERROR_CODE);
			}
			ret.setResultBody(Constant.OTHER_ERROR);
			ret.setResultDesc(Constant.OTHER_ERROR);
		}
    	
    	
    	return ret;
    }
    
    /**
     * 统一OkHttpClient调用
     * @param okRequest
     * @param outTime
     * @return
     */
    public Response getResponse(Request okRequest,int outTime) throws IOException{
    	OkHttpClient client = okHttpClient.newBuilder()
                .connectTimeout(outTime, TimeUnit.MILLISECONDS)
                .readTimeout(outTime, TimeUnit.MILLISECONDS)
                .writeTimeout(outTime, TimeUnit.MILLISECONDS)
                .build();
    	
        return client.newCall(okRequest).execute();
    }
}
